@@ -24,12 +24,12 @@
 #include "storage/data_database.h"
 #include "storage/data_database_writer.h"
 #include "storage/data_database_reader.h"
-#include "data_classifier.h"
-#include "data_classifier_type.h"
-#include "data_diagram.h"
+#include "entity/data_classifier.h"
+#include "entity/data_classifier_type.h"
+#include "entity/data_diagram.h"
 #include "set/data_small_set.h"
-#include "data_feature.h"
-#include "data_relationship.h"
+#include "entity/data_feature.h"
+#include "entity/data_relationship.h"
 #include <stdio.h>
 #include <stdbool.h>
 
@@ -43,6 +43,9 @@ struct ctrl_classifier_controller_struct {
     ctrl_consistency_checker_t consistency_checker;  /*!< own instance of a consistency checker */
     ctrl_undo_redo_list_t *undo_redo_list;  /*!< pointer to external ctrl_undo_redo_list_t */
     ctrl_classifier_trigger_t *policy_enforcer;  /*!< pointer to external ctrl_classifier_trigger_t */
+
+    data_feature_t temp_feature;
+    data_relationship_t temp_relationship;
 };
 
 typedef struct ctrl_classifier_controller_struct ctrl_classifier_controller_t;
@@ -92,7 +95,7 @@ void ctrl_classifier_controller_destroy ( ctrl_classifier_controller_t *this_ );
 u8_error_t ctrl_classifier_controller_create_classifier ( ctrl_classifier_controller_t *this_,
                                                           const data_classifier_t *new_classifier,
                                                           ctrl_undo_redo_action_boundary_t add_to_latest_undo_set,
-                                                          data_row_id_t* out_new_id
+                                                          data_row_t* out_new_id
                                                         );
 
 /*!
@@ -110,7 +113,7 @@ u8_error_t ctrl_classifier_controller_create_classifier ( ctrl_classifier_contro
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t ctrl_classifier_controller_delete_classifier ( ctrl_classifier_controller_t *this_,
-                                                          data_row_id_t obj_id,
+                                                          data_row_t obj_id,
                                                           ctrl_undo_redo_action_boundary_t add_to_latest_undo_set
                                                         );
 
@@ -123,7 +126,7 @@ u8_error_t ctrl_classifier_controller_delete_classifier ( ctrl_classifier_contro
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_main_type ( ctrl_classifier_controller_t *this_,
-                                                                    data_row_id_t classifier_id,
+                                                                    data_row_t classifier_id,
                                                                     data_classifier_type_t new_classifier_main_type
                                                                   );
 
@@ -136,7 +139,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_main_type ( ctrl_classif
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_stereotype ( ctrl_classifier_controller_t *this_,
-                                                                     data_row_id_t classifier_id,
+                                                                     data_row_t classifier_id,
                                                                      const char* new_classifier_stereotype
                                                                    );
 
@@ -152,7 +155,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_stereotype ( ctrl_classi
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_name ( ctrl_classifier_controller_t *this_,
-                                                               data_row_id_t classifier_id,
+                                                               data_row_t classifier_id,
                                                                const char* new_classifier_name
                                                              );
 
@@ -165,7 +168,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_name ( ctrl_classifier_c
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_description ( ctrl_classifier_controller_t *this_,
-                                                                      data_row_id_t classifier_id,
+                                                                      data_row_t classifier_id,
                                                                       const char* new_classifier_description
                                                                     );
 
@@ -178,7 +181,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_description ( ctrl_class
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_x_order ( ctrl_classifier_controller_t *this_,
-                                                                  data_row_id_t classifier_id,
+                                                                  data_row_t classifier_id,
                                                                   int32_t new_classifier_x_order
                                                                 );
 
@@ -191,7 +194,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_x_order ( ctrl_classifie
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_y_order ( ctrl_classifier_controller_t *this_,
-                                                                  data_row_id_t classifier_id,
+                                                                  data_row_t classifier_id,
                                                                   int32_t new_classifier_y_order
                                                                 );
 
@@ -205,7 +208,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_y_order ( ctrl_classifie
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_x_order_y_order ( ctrl_classifier_controller_t *this_,
-                                                                          data_row_id_t classifier_id,
+                                                                          data_row_t classifier_id,
                                                                           int32_t new_classifier_x_order,
                                                                           int32_t new_classifier_y_order
                                                                         );
@@ -219,7 +222,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_x_order_y_order ( ctrl_c
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_classifier_list_order ( ctrl_classifier_controller_t *this_,
-                                                                     data_row_id_t classifier_id,
+                                                                     data_row_t classifier_id,
                                                                      int32_t new_classifier_list_order
                                                                    );
 
@@ -240,7 +243,7 @@ u8_error_t ctrl_classifier_controller_update_classifier_list_order ( ctrl_classi
 u8_error_t ctrl_classifier_controller_create_feature ( ctrl_classifier_controller_t *this_,
                                                        const data_feature_t *new_feature,
                                                        ctrl_undo_redo_action_boundary_t add_to_latest_undo_set,
-                                                       data_row_id_t* out_new_id
+                                                       data_row_t* out_new_id
                                                      );
 
 /*!
@@ -257,7 +260,7 @@ u8_error_t ctrl_classifier_controller_create_feature ( ctrl_classifier_controlle
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t ctrl_classifier_controller_delete_feature ( ctrl_classifier_controller_t *this_,
-                                                       data_row_id_t obj_id,
+                                                       data_row_t obj_id,
                                                        ctrl_undo_redo_action_boundary_t add_to_latest_undo_set
                                                      );
 
@@ -270,7 +273,7 @@ u8_error_t ctrl_classifier_controller_delete_feature ( ctrl_classifier_controlle
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_feature_main_type ( ctrl_classifier_controller_t *this_,
-                                                                 data_row_id_t feature_id,
+                                                                 data_row_t feature_id,
                                                                  data_feature_type_t new_feature_type
                                                                );
 
@@ -283,7 +286,7 @@ u8_error_t ctrl_classifier_controller_update_feature_main_type ( ctrl_classifier
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_feature_key ( ctrl_classifier_controller_t *this_,
-                                                           data_row_id_t feature_id,
+                                                           data_row_t feature_id,
                                                            const char* new_feature_key
                                                          );
 
@@ -296,7 +299,7 @@ u8_error_t ctrl_classifier_controller_update_feature_key ( ctrl_classifier_contr
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_feature_value ( ctrl_classifier_controller_t *this_,
-                                                             data_row_id_t feature_id,
+                                                             data_row_t feature_id,
                                                              const char* new_feature_value
                                                            );
 
@@ -309,7 +312,7 @@ u8_error_t ctrl_classifier_controller_update_feature_value ( ctrl_classifier_con
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_feature_description ( ctrl_classifier_controller_t *this_,
-                                                                   data_row_id_t feature_id,
+                                                                   data_row_t feature_id,
                                                                    const char* new_feature_description
                                                                  );
 
@@ -322,7 +325,7 @@ u8_error_t ctrl_classifier_controller_update_feature_description ( ctrl_classifi
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_feature_list_order ( ctrl_classifier_controller_t *this_,
-                                                                  data_row_id_t feature_id,
+                                                                  data_row_t feature_id,
                                                                   int32_t new_feature_list_order
                                                                 );
 
@@ -343,7 +346,7 @@ u8_error_t ctrl_classifier_controller_update_feature_list_order ( ctrl_classifie
 u8_error_t ctrl_classifier_controller_create_relationship ( ctrl_classifier_controller_t *this_,
                                                             const data_relationship_t *new_relationship,
                                                             ctrl_undo_redo_action_boundary_t add_to_latest_undo_set,
-                                                            data_row_id_t* out_new_id
+                                                            data_row_t* out_new_id
                                                           );
 
 /*!
@@ -359,7 +362,7 @@ u8_error_t ctrl_classifier_controller_create_relationship ( ctrl_classifier_cont
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t ctrl_classifier_controller_delete_relationship ( ctrl_classifier_controller_t *this_,
-                                                            data_row_id_t obj_id,
+                                                            data_row_t obj_id,
                                                             ctrl_undo_redo_action_boundary_t add_to_latest_undo_set
                                                           );
 
@@ -372,7 +375,7 @@ u8_error_t ctrl_classifier_controller_delete_relationship ( ctrl_classifier_cont
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_relationship_main_type ( ctrl_classifier_controller_t *this_,
-                                                                      data_row_id_t relationship_id,
+                                                                      data_row_t relationship_id,
                                                                       data_relationship_type_t new_relationship_type
                                                                     );
 
@@ -385,7 +388,7 @@ u8_error_t ctrl_classifier_controller_update_relationship_main_type ( ctrl_class
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_relationship_stereotype ( ctrl_classifier_controller_t *this_,
-                                                                       data_row_id_t relationship_id,
+                                                                       data_row_t relationship_id,
                                                                        const char* new_relationship_stereotype
                                                                      );
 
@@ -398,7 +401,7 @@ u8_error_t ctrl_classifier_controller_update_relationship_stereotype ( ctrl_clas
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_relationship_name ( ctrl_classifier_controller_t *this_,
-                                                                 data_row_id_t relationship_id,
+                                                                 data_row_t relationship_id,
                                                                  const char* new_relationship_name
                                                                );
 
@@ -411,7 +414,7 @@ u8_error_t ctrl_classifier_controller_update_relationship_name ( ctrl_classifier
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_relationship_description ( ctrl_classifier_controller_t *this_,
-                                                                        data_row_id_t relationship_id,
+                                                                        data_row_t relationship_id,
                                                                         const char* new_relationship_description
                                                                       );
 
@@ -424,7 +427,7 @@ u8_error_t ctrl_classifier_controller_update_relationship_description ( ctrl_cla
  *  \return error id in case of an error, U8_ERROR_NONE otherwise
  */
 u8_error_t ctrl_classifier_controller_update_relationship_list_order ( ctrl_classifier_controller_t *this_,
-                                                                       data_row_id_t relationship_id,
+                                                                       data_row_t relationship_id,
                                                                        int32_t new_relationship_list_order
                                                                      );
 
@@ -432,7 +435,7 @@ u8_error_t ctrl_classifier_controller_update_relationship_list_order ( ctrl_clas
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
