@@ -9,7 +9,7 @@
  *  \brief Performs consistency checks in the database and can repair the database
  *
  *  - There shall be 1 root diagram
- *      - diagrams.parent_id == DATA_ROW_ID_VOID.
+ *      - diagrams.parent_id == DATA_ROW_VOID.
  *  - References shall be valid:
  *      - diagramelements.diagram_id,
  *      - diagramelements.classifier_id,
@@ -43,19 +43,12 @@
 #include "storage/data_database_writer.h"
 #include "storage/data_database_reader.h"
 #include "storage/data_database_consistency_checker.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "utf8stream/utf8stream_writer.h"
 #include <stdio.h>
 #include <stdbool.h>
 #include <stdint.h>
 
-/*!
- *  \brief constants to define maximum array sizes
- */
-enum ctrl_consistency_checker_max_enum {
-    CTRL_CONSISTENCY_CHECKER_MAX_DIAG_BUFFER = 16,  /*!< maximum size of diagram buffer */
-};
-
 /*!
  *  \brief data attributes needed for the consistency functions
  */
@@ -65,7 +58,7 @@ struct ctrl_consistency_checker_struct {
     data_database_reader_t *db_reader;  /*!< pointer to external database reader */
     data_database_consistency_checker_t db_checker;  /*!< own instance of a db_checker */
 
-    data_diagram_t temp_diagram_buffer[CTRL_CONSISTENCY_CHECKER_MAX_DIAG_BUFFER];  /*!< buffer for reading diagrams, e.g. root diagrams */
+    data_diagram_t temp_diagram;  /*!< buffer for reading one diagram after another */
 };
 
 typedef struct ctrl_consistency_checker_struct ctrl_consistency_checker_t;
@@ -262,7 +255,7 @@ u8_error_t ctrl_consistency_checker_private_ensure_valid_relationship_features (
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
