@@ -74,53 +74,35 @@ u8_error_t consistency_drop_invisibles_delete_invisible_relationships( consisten
     assert( NULL != deleted_diagramelement );
     u8_error_t result = U8_ERROR_NONE;
 
-    data_row_id_t classifier_id = data_diagramelement_get_classifier_row_id( deleted_diagramelement );
+    data_row_t classifier_id = data_diagramelement_get_classifier_row_id( deleted_diagramelement );
     data_small_set_t relations_to_delete;
     data_small_set_init( &relations_to_delete );
 
     /* load relationships to be checked */
-    uint32_t relationship_count = 0;
-    const u8_error_t d_err
-        = data_database_reader_get_relationships_by_classifier_id( (*this_).db_reader,
-                                                                   classifier_id,
-                                                                   CONSISTENCY_DROP_INVISIBLES_CONST_MAX_TEMP_RELATIONS,
-                                                                   &((*this_).private_temp_rel_buf),
-                                                                   &relationship_count
-                                                                 );
-    if ( d_err == U8_ERROR_ARRAY_BUFFER_EXCEEDED )
-    {
-        U8_LOG_ANOMALY( "The dereferenced classifier has more relationships than can be checked for being superfluous now." );
-        U8_TRACE_INFO_INT( "classifier has too many relationships:", classifier_id );
-        /* no further error propagation. */
-    }
-    else
-    {
-        result |= d_err;
-    }
-
+    data_relationship_iterator_t relationship_iterator;
+    result |= data_relationship_iterator_init_empty( &relationship_iterator );
+    result |= data_database_reader_get_relationships_by_classifier_id( (*this_).db_reader,
+                                                                       classifier_id,
+                                                                       &relationship_iterator
+                                                                     );
     if ( result == U8_ERROR_NONE )
     {
-        for ( uint_fast32_t rel_idx = 0; rel_idx < relationship_count; rel_idx ++ )
+        while( data_relationship_iterator_has_next( &relationship_iterator ) )
         {
-            const data_relationship_t *relation = &((*this_).private_temp_rel_buf[rel_idx]);
+            result |= data_relationship_iterator_next( &relationship_iterator, &((*this_).temp_relationship_buf) );
 
             bool visible = true;
             const u8_error_t vis_err
-                = consistency_drop_invisibles_private_has_relationship_a_diagram( this_, relation, &visible );
+                = consistency_drop_invisibles_private_has_relationship_a_diagram( this_, &((*this_).temp_relationship_buf), &visible );
 
-            if ( vis_err == U8_ERROR_ARRAY_BUFFER_EXCEEDED )
-            {
-                U8_LOG_ANOMALY( "A relationship is connected to a classifier that is too often referenced to check for being superfluous now." );
-                U8_TRACE_INFO_INT( "classifier or related classifier has too many diagramelements:", classifier_id );
-                /* no further error propagation. */
-            }
-            else if ( vis_err == U8_ERROR_NONE )
+            if ( vis_err == U8_ERROR_NONE )
             {
                 if ( ! visible )
                 {
                     /* invisible relationship found */
                     /* this must be copied into a local data set to make this class re-entrant for recursive calls */
-                    result |= data_small_set_add_obj( &relations_to_delete, data_relationship_get_data_id( relation ) );
+                    const data_id_t relation_to_delete = data_relationship_get_data_id( &((*this_).temp_relationship_buf) );
+                    result |= data_small_set_add_obj( &relations_to_delete, relation_to_delete );
                 }
             }
             else
@@ -129,9 +111,15 @@ u8_error_t consistency_drop_invisibles_delete_invisible_relationships( consisten
             }
         }
     }
+    else
+    {
+        U8_LOG_WARNING( "Relationships of the deleted classifier cannot be checked for being superfluous now." );
+        U8_TRACE_INFO_INT( "classifier has unckecked relationships:", classifier_id );
+    }
+    result |= data_relationship_iterator_destroy( &relationship_iterator );
+    /* note that relationship_iterator cannot be used here any longer due to re-entrancy by recursion */
 
     /* delete all found relationship */
-    /* note that (*this_).private_temp_rel_buf cannot be used here any longer due to re-entrancy by recursion */
     const uint32_t relations_count = data_small_set_get_count( &relations_to_delete );
     for ( uint32_t index2 = 0; index2 < relations_count; index2 ++ )
     {
@@ -158,8 +146,8 @@ u8_error_t consistency_drop_invisibles_private_has_relationship_a_diagram( consi
     assert( NULL != out_result );
     u8_error_t result = U8_ERROR_NONE;
 
-    const data_row_id_t from_classifier_id = data_relationship_get_from_classifier_row_id( relation );
-    const data_row_id_t to_classifier_id = data_relationship_get_to_classifier_row_id( relation );
+    const data_row_t from_classifier_id = data_relationship_get_from_classifier_row_id( relation );
+    const data_row_t to_classifier_id = data_relationship_get_to_classifier_row_id( relation );
 
     if ( from_classifier_id == to_classifier_id )
     {
@@ -168,27 +156,25 @@ u8_error_t consistency_drop_invisibles_private_has_relationship_a_diagram( consi
     }
     else
     {
+        bool same_diag = false;
         data_small_set_t from_diagrams;
         data_small_set_init( &from_diagrams );
-        u8_error_t from_err;
 
         /* load diagramelements that are referenced by the relationships from end */
         {
-            uint32_t from_diagramelement_count = 0;
-            from_err
-                = data_database_reader_get_diagramelements_by_classifier_id( (*this_).db_reader,
-                                                                             from_classifier_id,
-                                                                             CONSISTENCY_DROP_INVISIBLES_CONST_MAX_TEMP_DIAGELES,
-                                                                             &((*this_).private_temp_diagele_buf),
-                                                                             &from_diagramelement_count
-                                                                           );
-            if ( from_err == U8_ERROR_NONE )
+            data_diagramelement_iterator_t diagramelement_iterator;
+            result |= data_diagramelement_iterator_init_empty( &diagramelement_iterator );
+            result |= data_database_reader_get_diagramelements_by_classifier_id( (*this_).db_reader,
+                                                                                 from_classifier_id,
+                                                                                 &diagramelement_iterator
+                                                                               );
+            if ( result == U8_ERROR_NONE )
             {
-                /* copy diagram ids to id-set */
-                for ( uint_fast32_t from_idx = 0; from_idx < from_diagramelement_count; from_idx ++ )
+                while ( data_diagramelement_iterator_has_next( &diagramelement_iterator ) )
                 {
+                    result |= data_diagramelement_iterator_next( &diagramelement_iterator, &((*this_).temp_diagelement_buf) );
                     const data_id_t from_diag_id
-                        = data_diagramelement_get_diagram_data_id ( &((*this_).private_temp_diagele_buf[from_idx]) );
+                        = data_diagramelement_get_diagram_data_id ( &((*this_).temp_diagelement_buf) );
                     const u8_error_t ins_err
                         = data_small_set_add_obj( &from_diagrams, from_diag_id );
                     if ( ins_err == U8_ERROR_DUPLICATE_ID )
@@ -197,44 +183,39 @@ u8_error_t consistency_drop_invisibles_private_has_relationship_a_diagram( consi
                     }
                     else
                     {
-                        from_err |= ins_err;
+                        result |= ins_err;
                     }
                 }
             }
+            result |= data_diagramelement_iterator_destroy( &diagramelement_iterator );
         }
 
         /* load diagramelements that are referenced by the relationships to end */
-        uint32_t to_diagramelement_count = 0;
-        const u8_error_t to_err
-            = data_database_reader_get_diagramelements_by_classifier_id( (*this_).db_reader,
-                                                                         to_classifier_id,
-                                                                         CONSISTENCY_DROP_INVISIBLES_CONST_MAX_TEMP_DIAGELES,
-                                                                         &((*this_).private_temp_diagele_buf),
-                                                                         &to_diagramelement_count
-                                                                       );
+        data_diagramelement_iterator_t diagramelement_iterator2;
+        result |= data_diagramelement_iterator_init_empty( &diagramelement_iterator2 );
+        result |= data_database_reader_get_diagramelements_by_classifier_id( (*this_).db_reader,
+                                                                             to_classifier_id,
+                                                                             &diagramelement_iterator2
+                                                                           );
 
         /* check for same diagram */
-        if (( from_err == U8_ERROR_NONE )&&( to_err == U8_ERROR_NONE ))
+        if ( result == U8_ERROR_NONE )
         {
-            bool same_diag = false;
-            for ( uint_fast32_t to_idx = 0; to_idx < to_diagramelement_count; to_idx ++ )
+            while ( data_diagramelement_iterator_has_next( &diagramelement_iterator2 ) )
             {
+                result |= data_diagramelement_iterator_next( &diagramelement_iterator2, &((*this_).temp_diagelement_buf) );
                 const data_id_t to_diag_id
-                    = data_diagramelement_get_diagram_data_id ( &((*this_).private_temp_diagele_buf[to_idx]) );
+                    = data_diagramelement_get_diagram_data_id ( &((*this_).temp_diagelement_buf) );
                 if ( data_small_set_contains( &from_diagrams, to_diag_id ) )
                 {
                     same_diag = true;
                 }
             }
-            *out_result = same_diag;
         }
-        else
-        {
-            result |= from_err;
-            result |= to_err;
-        }
-
+        result |= data_diagramelement_iterator_destroy( &diagramelement_iterator2 );
         data_small_set_destroy( &from_diagrams );
+
+        *out_result = same_diag;
     }
 
     U8_TRACE_END_ERR( result );
@@ -243,7 +224,7 @@ u8_error_t consistency_drop_invisibles_private_has_relationship_a_diagram( consi
 
 
 /*
-Copyright 2018-2024 Andreas Warnke
+Copyright 2018-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
