@@ -5,8 +5,8 @@
 #include "ctrl_diagram_controller.h"
 #include "storage/data_database.h"
 #include "storage/data_database_reader.h"
-#include "data_diagram.h"
-#include "data_diagram_type.h"
+#include "entity/data_diagram.h"
+#include "entity/data_diagram_type.h"
 #include "test_fixture.h"
 #include "test_expect.h"
 #include "test_environment_assert.h"
@@ -64,32 +64,31 @@ static test_case_result_t create_read_modify_read( test_fixture_t *fix )
     assert( fix != NULL );
     u8_error_t ctrl_err;
     u8_error_t data_err;
-    const static data_row_id_t PARENT_ID = 17;
-    data_row_id_t diagram_id;
-    uint32_t read_diagrams_count;
-    data_diagram_t read_diagrams[2];
+    const static data_row_t PARENT_ID = 17;
+    data_row_t diagram_id;
+    data_diagram_t read_diagram;
     ctrl_diagram_controller_t *diag_ctrl;
     diag_ctrl = ctrl_controller_get_diagram_control_ptr( &((*fix).controller) );
 
     /* create a record */
     {
-        diagram_id = DATA_ROW_ID_VOID;
+        diagram_id = DATA_ROW_VOID;
         ctrl_err = ctrl_diagram_controller_private_create_child_diagram ( diag_ctrl, PARENT_ID, DATA_DIAGRAM_TYPE_UML_PACKAGE_DIAGRAM, "diagram_name", &diagram_id );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_EXPECT( DATA_ROW_ID_VOID != diagram_id );
+        TEST_EXPECT( DATA_ROW_VOID != diagram_id );
     }
 
     /* read this record */
     {
-        data_diagram_init_empty( &(read_diagrams[0]) );
-        data_err = data_database_reader_get_diagram_by_id ( &((*fix).db_reader), diagram_id, &(read_diagrams[0]) );
+        data_diagram_init_empty( &(read_diagram) );
+        data_err = data_database_reader_get_diagram_by_id ( &((*fix).db_reader), diagram_id, &(read_diagram) );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( PARENT_ID, data_diagram_get_parent_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_PACKAGE_DIAGRAM, data_diagram_get_diagram_type( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "diagram_name", data_diagram_get_name_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "", data_diagram_get_description_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, data_diagram_get_list_order( &(read_diagrams[0]) ) );
+        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( PARENT_ID, data_diagram_get_parent_row_id( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_PACKAGE_DIAGRAM, data_diagram_get_diagram_type( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "diagram_name", data_diagram_get_name_const( &(read_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "", data_diagram_get_description_const( &(read_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( 0, data_diagram_get_list_order( &(read_diagram) ) );
     }
 
     /* modify this record */
@@ -116,32 +115,27 @@ static test_case_result_t create_read_modify_read( test_fixture_t *fix )
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
     }
 
-    /* search several records, result array too small */
+    /* search several records */
     {
-        data_err = data_database_reader_get_diagrams_by_parent_id ( &((*fix).db_reader), PARENT_ID, 0, &read_diagrams, &read_diagrams_count );
-        TEST_EXPECT_EQUAL_INT( U8_ERROR_ARRAY_BUFFER_EXCEEDED, data_err );
-        TEST_EXPECT_EQUAL_INT( 0, read_diagrams_count );
-        /* check that old data is not overwritten: */
-        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( PARENT_ID, data_diagram_get_parent_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_PACKAGE_DIAGRAM, data_diagram_get_diagram_type( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "diagram_name", data_diagram_get_name_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "", data_diagram_get_description_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, data_diagram_get_list_order( &(read_diagrams[0]) ) );
-    }
-
-    /* search several records, result array sufficient */
-    {
-        data_err = data_database_reader_get_diagrams_by_parent_id ( &((*fix).db_reader), PARENT_ID, 2, &read_diagrams, &read_diagrams_count );
+        data_diagram_iterator_t diagram_iterator;
+        data_err = data_diagram_iterator_init_empty( &diagram_iterator );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( 1, read_diagrams_count );
+        data_err = data_database_reader_get_diagrams_by_parent_id ( &((*fix).db_reader), PARENT_ID, &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( true, data_diagram_iterator_has_next( &diagram_iterator ) );
         /* check that new data is available */
-        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( PARENT_ID, data_diagram_get_parent_row_id( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_USE_CASE_DIAGRAM, data_diagram_get_diagram_type( &(read_diagrams[0]) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "\"new\" diagram name", data_diagram_get_name_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "'new' diagram\ndescription", data_diagram_get_description_const( &(read_diagrams[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( -4321, data_diagram_get_list_order( &(read_diagrams[0]) ) );
+        data_err = data_diagram_iterator_next( &diagram_iterator, &(read_diagram) );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( PARENT_ID, data_diagram_get_parent_row_id( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_USE_CASE_DIAGRAM, data_diagram_get_diagram_type( &(read_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "\"new\" diagram name", data_diagram_get_name_const( &(read_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "'new' diagram\ndescription", data_diagram_get_description_const( &(read_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( -4321, data_diagram_get_list_order( &(read_diagram) ) );
+        /* check for end */
+        TEST_EXPECT_EQUAL_INT( false, data_diagram_iterator_has_next( &diagram_iterator ) );
+        data_err = data_diagram_iterator_destroy( &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
     }
 
     /* search several record ids to a result set */
@@ -167,28 +161,26 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
     u8_error_t data_err;
     ctrl_classifier_controller_t *classifier_ctrl;
     ctrl_diagram_controller_t *diagram_ctrl;
-    data_row_id_t diagram_id;
-    data_row_id_t classifier_id;
+    data_row_t diagram_id;
+    data_row_t classifier_id;
     classifier_ctrl = ctrl_controller_get_classifier_control_ptr( &((*fix).controller) );
     diagram_ctrl = ctrl_controller_get_diagram_control_ptr( &((*fix).controller) );
-    uint32_t read_vis_classifiers_count;
-    data_visible_classifier_t read_vis_classifiers[2];
+    data_visible_classifier_t read_vis_classifier;
     data_diagramelement_t *diag_element_ptr;
-    data_row_id_t diag_element_id;
+    data_row_t diag_element_id;
     data_diagramelement_t diag_element;
-    uint32_t out_diagram_count;
-    data_diagram_t out_diagram[2];
+    data_diagram_t out_diagram;
 
     /* create the root diagram */
     {
-        diagram_id = DATA_ROW_ID_VOID;
+        diagram_id = DATA_ROW_VOID;
         ctrl_err = ctrl_diagram_controller_create_root_diagram_if_not_exists ( diagram_ctrl,
                                                                                DATA_DIAGRAM_TYPE_UML_ACTIVITY_DIAGRAM,
                                                                                "root_diagram",
                                                                                &diagram_id
                                                                              );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
-        TEST_EXPECT( DATA_ROW_ID_VOID != diagram_id );
+        TEST_EXPECT( DATA_ROW_VOID != diagram_id );
     }
 
     /* create a classifier */
@@ -211,7 +203,7 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
                                                                 );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_classifier_destroy ( &new_classifier );
-        TEST_EXPECT( DATA_ROW_ID_VOID != classifier_id );
+        TEST_EXPECT( DATA_ROW_VOID != classifier_id );
     }
 
     /* create a diagramelement */
@@ -221,7 +213,7 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
                                        diagram_id,
                                        classifier_id,
                                        DATA_DIAGRAMELEMENT_FLAG_NONE,
-                                       DATA_ROW_ID_VOID
+                                       DATA_ROW_VOID
                                      );
         ctrl_err = ctrl_diagram_controller_create_diagramelement ( diagram_ctrl,
                                                                    &new_diagele,
@@ -230,23 +222,31 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
                                                                  );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, ctrl_err );
         data_diagramelement_destroy ( &new_diagele );
-        TEST_EXPECT( DATA_ROW_ID_VOID != diag_element_id );
+        TEST_EXPECT( DATA_ROW_VOID != diag_element_id );
     }
 
     /* get the id of the diagramelement */
     {
-        data_err = data_database_reader_get_classifiers_by_diagram_id( &((*fix).db_reader),
-                                                                       diagram_id,
-                                                                       2,
-                                                                       &read_vis_classifiers,
-                                                                       &read_vis_classifiers_count
-                                                                     );
+        data_visible_classifier_iterator_t visible_classifier_iterator;
+        data_err = data_visible_classifier_iterator_init_empty( &visible_classifier_iterator );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( 1, read_vis_classifiers_count );
-        diag_element_ptr = data_visible_classifier_get_diagramelement_ptr( &(read_vis_classifiers[0]) );
+        data_err = data_database_reader_get_visible_classifiers_by_diagram_id( &((*fix).db_reader),
+                                                                               diagram_id,
+                                                                               &visible_classifier_iterator
+                                                                             );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( true, data_visible_classifier_iterator_has_next( &visible_classifier_iterator ) );
+
+        data_err = data_visible_classifier_iterator_next( &visible_classifier_iterator, &read_vis_classifier );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        diag_element_ptr = data_visible_classifier_get_diagramelement_ptr( &read_vis_classifier );
         TEST_EXPECT_EQUAL_INT( diagram_id, data_diagramelement_get_diagram_row_id( diag_element_ptr ) );
         TEST_EXPECT_EQUAL_INT( classifier_id, data_diagramelement_get_classifier_row_id( diag_element_ptr ) );
         diag_element_id = data_diagramelement_get_row_id( diag_element_ptr );
+
+        TEST_EXPECT_EQUAL_INT( false, data_visible_classifier_iterator_has_next( &visible_classifier_iterator ) );
+        data_err = data_visible_classifier_iterator_destroy( &visible_classifier_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
     }
 
     /* get the data_diagramelement_t by id */
@@ -256,25 +256,34 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
         TEST_EXPECT_EQUAL_INT( diagram_id, data_diagramelement_get_diagram_row_id( &diag_element ) );
         TEST_EXPECT_EQUAL_INT( classifier_id, data_diagramelement_get_classifier_row_id( &diag_element ) );
         TEST_EXPECT_EQUAL_INT( diag_element_id, data_diagramelement_get_row_id( &diag_element ) );
-        TEST_EXPECT_EQUAL_INT( DATA_ROW_ID_VOID, data_diagramelement_get_focused_feature_row_id( &diag_element ) );
+        TEST_EXPECT_EQUAL_INT( DATA_ROW_VOID, data_diagramelement_get_focused_feature_row_id( &diag_element ) );
     }
 
     /* get all diagrams by classifier id */
     {
+        data_diagram_iterator_t diagram_iterator;
+        data_err = data_diagram_iterator_init_empty( &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+
         data_err = data_database_reader_get_diagrams_by_classifier_id( &((*fix).db_reader),
                                                                        classifier_id,
-                                                                       2,
-                                                                       &out_diagram,
-                                                                       &out_diagram_count
+                                                                       &diagram_iterator
                                                                      );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( 1, out_diagram_count );
-        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(out_diagram[0]) ) );
-        TEST_EXPECT_EQUAL_INT( DATA_ROW_ID_VOID, data_diagram_get_parent_row_id( &(out_diagram[0]) ) );
-        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_ACTIVITY_DIAGRAM, data_diagram_get_diagram_type( &(out_diagram[0]) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "root_diagram", data_diagram_get_name_const( &(out_diagram[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, strcmp( "", data_diagram_get_description_const( &(out_diagram[0]) ) ) );
-        TEST_EXPECT_EQUAL_INT( 0, data_diagram_get_list_order( &(out_diagram[0]) ) );
+        TEST_EXPECT_EQUAL_INT( true, data_diagram_iterator_has_next( &diagram_iterator ) );
+
+        data_err = data_diagram_iterator_next( &diagram_iterator, &(out_diagram) );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( diagram_id, data_diagram_get_row_id( &(out_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( DATA_ROW_VOID, data_diagram_get_parent_row_id( &(out_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( DATA_DIAGRAM_TYPE_UML_ACTIVITY_DIAGRAM, data_diagram_get_diagram_type( &(out_diagram) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "root_diagram", data_diagram_get_name_const( &(out_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( 0, strcmp( "", data_diagram_get_description_const( &(out_diagram) ) ) );
+        TEST_EXPECT_EQUAL_INT( 0, data_diagram_get_list_order( &(out_diagram) ) );
+
+        TEST_EXPECT_EQUAL_INT( false, data_diagram_iterator_has_next( &diagram_iterator ) );
+        data_err = data_diagram_iterator_destroy( &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
     }
 
     /* delete the diagramelement */
@@ -294,16 +303,23 @@ static test_case_result_t create_diagramelements_and_delete( test_fixture_t *fix
 
     /* get all diagrams by classifier id */
     {
-        data_err = data_database_reader_get_diagrams_by_classifier_id ( &((*fix).db_reader), classifier_id, 2, &out_diagram, &out_diagram_count );
+        data_diagram_iterator_t diagram_iterator;
+        data_err = data_diagram_iterator_init_empty( &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+
+        data_err = data_database_reader_get_diagrams_by_classifier_id ( &((*fix).db_reader), classifier_id, &diagram_iterator );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
+        TEST_EXPECT_EQUAL_INT( false, data_diagram_iterator_has_next( &diagram_iterator ) );
+
+        data_err = data_diagram_iterator_destroy( &diagram_iterator );
         TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, data_err );
-        TEST_EXPECT_EQUAL_INT( 0, out_diagram_count );
     }
     return TEST_CASE_RESULT_OK;
 }
 
 
 /*
- * Copyright 2016-2024 Andreas Warnke
+ * Copyright 2016-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
