@@ -9,8 +9,9 @@
  *  \brief Defines ids of a diagram, classifier, feature and relationship needed to describe a search result
  */
 
-#include "data_id.h"
-#include "data_row_id.h"
+#include "entity/data_id.h"
+#include "entity/data_row.h"
+#include "entity/data_type.h"
 
 /*!
  *  \brief constants for max string sizes
@@ -25,7 +26,7 @@ enum data_search_result_max_enum {
  */
 struct data_search_result_struct {
     data_id_t match_object_id;  /*!< the object id of the found object */
-    int  match_type;  /*!< the type of the found object, stored as int */
+    data_type_t match_object_type;  /*!< the type of the found object */
     utf8stringbuf_t match_object_name;  /*!< name of the found object */
     char private_match_name_buffer[DATA_SEARCH_RESULT_MAX_NAME_SIZE];
     data_id_t src_classifier_id;  /*!< in case of feature or relationship, the source classifier id */
@@ -40,12 +41,12 @@ typedef struct data_search_result_struct data_search_result_t;
  *
  *  \param this_ pointer to own object attributes
  *  \param match_id matching diagram id
- *  \param match_type matching objects type, data_diagram_type_t stored as int
+ *  \param match_type matching objects type, data_diagram_type_t
  *  \param match_name matching object name, must not be NULL
  */
 static inline void data_search_result_init_diagram ( data_search_result_t *this_,
-                                                     data_row_id_t match_id,
-                                                     int match_type,
+                                                     data_row_t match_id,
+                                                     data_diagram_type_t match_type,
                                                      const char* match_name
                                                    );
 
@@ -54,15 +55,15 @@ static inline void data_search_result_init_diagram ( data_search_result_t *this_
  *
  *  \param this_ pointer to own object attributes
  *  \param match_id matching classifier id
- *  \param match_type matching objects type, data_classifier_type_t stored as int
+ *  \param match_type matching objects type, data_classifier_type_t 
  *  \param match_name matching object name, must not be NULL
  *  \param diagram_id diagram id where the matching object is visible
  */
 static inline void data_search_result_init_classifier ( data_search_result_t *this_,
-                                                        data_row_id_t match_id,
-                                                        int match_type,
+                                                        data_row_t match_id,
+                                                        data_classifier_type_t match_type,
                                                         const char* match_name,
-                                                        data_row_id_t diagram_id
+                                                        data_row_t diagram_id
                                                       );
 
 /*!
@@ -70,17 +71,17 @@ static inline void data_search_result_init_classifier ( data_search_result_t *th
  *
  *  \param this_ pointer to own object attributes
  *  \param match_id matching feature id
- *  \param match_type matching objects type, data_feature_type_t stored as int
+ *  \param match_type matching objects type, data_feature_type_t
  *  \param match_name matching object name, must not be NULL
  *  \param classifier_id classifier of matching feature
  *  \param diagram_id diagram id where the matching feature is visible
  */
 static inline void data_search_result_init_feature ( data_search_result_t *this_,
-                                                     data_row_id_t match_id,
-                                                     int match_type,
+                                                     data_row_t match_id,
+                                                     data_feature_type_t match_type,
                                                      const char* match_name,
-                                                     data_row_id_t classifier_id,
-                                                     data_row_id_t diagram_id
+                                                     data_row_t classifier_id,
+                                                     data_row_t diagram_id
                                                    );
 
 /*!
@@ -88,19 +89,19 @@ static inline void data_search_result_init_feature ( data_search_result_t *this_
  *
  *  \param this_ pointer to own object attributes
  *  \param match_id matching relationship id
- *  \param match_type matching objects type, data_relationship_type_t stored as int
+ *  \param match_type matching objects type, data_relationship_type_t
  *  \param match_name matching object name, must not be NULL
  *  \param from_classifier_id from classifier of matching relationship
  *  \param to_classifier_id to classifier of matching relationship
  *  \param diagram_id diagram id where the matching relationship is visible
  */
 static inline void data_search_result_init_relationship ( data_search_result_t *this_,
-                                                          data_row_id_t match_id,
-                                                          int match_type,
+                                                          data_row_t match_id,
+                                                          data_relationship_type_t match_type,
                                                           const char* match_name,
-                                                          data_row_id_t from_classifier_id,
-                                                          data_row_id_t to_classifier_id,
-                                                          data_row_id_t diagram_id
+                                                          data_row_t from_classifier_id,
+                                                          data_row_t to_classifier_id,
+                                                          data_row_t diagram_id
                                                         );
 
 /*!
@@ -142,21 +143,13 @@ static inline data_id_t *data_search_result_get_match_id_ptr ( data_search_resul
  */
 static inline const data_id_t *data_search_result_get_match_id_const ( const data_search_result_t *this_ );
 
-/*!
- *  \brief gets the table of the match object from its id
- *
- *  \param this_ pointer to own object attributes
- *  \return the table of the match object
- */
-static inline data_table_t data_search_result_get_match_table ( const data_search_result_t *this_ );
-
 /*!
  *  \brief gets the match object type
  *
  *  \param this_ pointer to own object attributes
  *  \return the type of the match object
  */
-static inline int data_search_result_get_match_type ( const data_search_result_t *this_ );
+static inline data_type_t data_search_result_get_match_type ( const data_search_result_t *this_ );
 
 /*!
  *  \brief gets the match object name
@@ -251,7 +244,7 @@ static inline void data_search_result_trace ( const data_search_result_t *this_
 
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
