@@ -11,16 +11,18 @@
 
 #include "storage/data_database_listener.h"
 #include "storage/data_database_listener_signal.h"
-#include "storage/data_database_iterator_classifiers.h"
+#include "storage/data_classifier_iterator.h"
+#include "storage/data_feature_iterator.h"
+#include "storage/data_relationship_iterator.h"
 #include "storage/data_database.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "u8/u8_error.h"
-#include "data_classifier.h"
+#include "entity/data_classifier.h"
 #include "set/data_visible_classifier.h"
 #include "set/data_small_set.h"
-#include "data_feature.h"
-#include "data_relationship.h"
-#include "data_row_id.h"
+#include "entity/data_feature.h"
+#include "entity/data_relationship.h"
+#include "entity/data_row.h"
 #include <stdio.h>
 #include <sqlite3.h>
 #include <stdbool.h>
@@ -35,16 +37,26 @@ struct data_database_classifier_reader_struct {
     sqlite3_stmt *statement_classifier_by_id;
     sqlite3_stmt *statement_classifier_by_name;
     sqlite3_stmt *statement_classifier_by_uuid;
-    sqlite3_stmt *statement_classifiers_by_diagram_id;
+    sqlite3_stmt *statement_classifiers_all;
+    bool statement_classifiers_all_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
+    sqlite3_stmt *statement_classifiers_all_hierarchical;
+    bool statement_classifiers_all_hierarchical_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
+
     sqlite3_stmt *statement_feature_by_id;
     sqlite3_stmt *statement_feature_by_uuid;
     sqlite3_stmt *statement_features_by_classifier_id;
+    bool statement_features_by_classifier_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
     sqlite3_stmt *statement_features_by_diagram_id;
+    bool statement_features_by_diagram_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
+
     sqlite3_stmt *statement_relationship_by_id;
     sqlite3_stmt *statement_relationship_by_uuid;
     sqlite3_stmt *statement_relationships_by_classifier_id;
+    bool statement_relationships_by_classifier_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
     sqlite3_stmt *statement_relationships_by_feature_id;
+    bool statement_relationships_by_feature_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
     sqlite3_stmt *statement_relationships_by_diagram_id;
+    bool statement_relationships_by_diagram_id_borrowed;  /*!< flag that indicates if the statement is borrowed by an iterator */
 };
 
 typedef struct data_database_classifier_reader_struct data_database_classifier_reader_t;
@@ -82,7 +94,7 @@ u8_error_t data_database_classifier_reader_destroy ( data_database_classifier_re
  *          E.g. U8_ERROR_DB_STRUCTURE if id does not exist or U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_classifier_by_id ( data_database_classifier_reader_t *this_,
-                                                                  data_row_id_t id,
+                                                                  data_row_t id,
                                                                   data_classifier_t *out_classifier
                                                                 );
 
@@ -114,27 +126,6 @@ u8_error_t data_database_classifier_reader_get_classifier_by_uuid ( data_databas
                                                                     data_classifier_t *out_classifier
                                                                   );
 
-/*!
- *  \brief reads all classifiers of a diagram from the database.
- *
- *  If a classifier is contained multiple times in a diagram, it is returned multiple times in the out_visible_classifier result list.
- *
- *  \param this_ pointer to own object attributes
- *  \param diagram_id id of the containing diagram
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_visible_classifier array of classifiers (and diagramelements) read from the database (in case of success)
- *  \param[out] out_visible_classifier_count number of classifier records stored in out_visible_classifier
- *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
- */
-u8_error_t data_database_classifier_reader_get_classifiers_by_diagram_id ( data_database_classifier_reader_t *this_,
-                                                                           data_row_id_t diagram_id,
-                                                                           uint32_t max_out_array_size,
-                                                                           data_visible_classifier_t (*out_visible_classifier)[],
-                                                                           uint32_t *out_visible_classifier_count
-                                                                         );
-
 /*!
  *  \brief iterates over all classifiers from the database.
  *
@@ -147,10 +138,10 @@ u8_error_t data_database_classifier_reader_get_classifiers_by_diagram_id ( data_
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  *          E.g. U8_ERROR_NO_DB if the database is not open.
  */
-u8_error_t data_database_classifier_reader_get_all_classifiers_iterator ( data_database_classifier_reader_t *this_,
-                                                                          bool hierarchical,
-                                                                          data_database_iterator_classifiers_t *io_classifier_iterator
-                                                                        );
+u8_error_t data_database_classifier_reader_get_all_classifiers ( data_database_classifier_reader_t *this_,
+                                                                 bool hierarchical,
+                                                                 data_classifier_iterator_t *io_classifier_iterator
+                                                               );
 
 /* ================================ FEATURE ================================ */
 
@@ -164,7 +155,7 @@ u8_error_t data_database_classifier_reader_get_all_classifiers_iterator ( data_d
  *          E.g. U8_ERROR_DB_STRUCTURE if id does not exist or U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_feature_by_id ( data_database_classifier_reader_t *this_,
-                                                               data_row_id_t id,
+                                                               data_row_t id,
                                                                data_feature_t *out_feature
                                                              );
 
@@ -186,18 +177,14 @@ u8_error_t data_database_classifier_reader_get_feature_by_uuid ( data_database_c
  *
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the parent classifier
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_feature array of features read from the database (in case of success)
- *  \param[out] out_feature_count number of feature records stored in out_feature
+ *  \param[in,out] io_feature_iterator iterator over features of selected classifier. The caller is responsible
+ *                                     for initializing before and destroying this object afterwards.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
+ *          U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_features_by_classifier_id ( data_database_classifier_reader_t *this_,
-                                                                           data_row_id_t classifier_id,
-                                                                           uint32_t max_out_array_size,
-                                                                           data_feature_t (*out_feature)[],
-                                                                           uint32_t *out_feature_count
+                                                                           data_row_t classifier_id,
+                                                                           data_feature_iterator_t *io_feature_iterator
                                                                          );
 
 /*!
@@ -207,18 +194,14 @@ u8_error_t data_database_classifier_reader_get_features_by_classifier_id ( data_
  *
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the containing diagram
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_feature array of features read from the database (in case of success)
- *  \param[out] out_feature_count number of feature records stored in out_feature
+ *  \param[in,out] io_feature_iterator iterator over features of selected classifier. The caller is responsible
+ *                                     for initializing before and destroying this object afterwards.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
+ *          U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_database_classifier_reader_t *this_,
-                                                                        data_row_id_t diagram_id,
-                                                                        uint32_t max_out_array_size,
-                                                                        data_feature_t (*out_feature)[],
-                                                                        uint32_t *out_feature_count
+                                                                        data_row_t diagram_id,
+                                                                        data_feature_iterator_t *io_feature_iterator
                                                                       );
 
 /* ================================ RELATIONSHIP ================================ */
@@ -233,7 +216,7 @@ u8_error_t data_database_classifier_reader_get_features_by_diagram_id ( data_dat
  *          E.g. U8_ERROR_DB_STRUCTURE if id does not exist or U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_relationship_by_id ( data_database_classifier_reader_t *this_,
-                                                                    data_row_id_t id,
+                                                                    data_row_t id,
                                                                     data_relationship_t *out_relationship
                                                                   );
 
@@ -258,18 +241,14 @@ u8_error_t data_database_classifier_reader_get_relationship_by_uuid ( data_datab
  *
  *  \param this_ pointer to own object attributes
  *  \param classifier_id id of the source(from) or destination(to) classifier
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_relationship array of relationships read from the database (in case of success)
- *  \param[out] out_relationship_count number of relationship records stored in out_relationship
+ *  \param[in,out] io_relationship_iterator iterator over relationships of selected classifier. The caller is responsible
+ *                                          for initializing before and destroying this object afterwards.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
+ *          U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_relationships_by_classifier_id ( data_database_classifier_reader_t *this_,
-                                                                                data_row_id_t classifier_id,
-                                                                                uint32_t max_out_array_size,
-                                                                                data_relationship_t (*out_relationship)[],
-                                                                                uint32_t *out_relationship_count
+                                                                                data_row_t classifier_id,
+                                                                                data_relationship_iterator_t *io_relationship_iterator
                                                                               );
 
 /*!
@@ -278,19 +257,15 @@ u8_error_t data_database_classifier_reader_get_relationships_by_classifier_id (
  *  This includes relationships where the feature is source-only, destination-only or both.
  *
  *  \param this_ pointer to own object attributes
- *  \param feature_id id of the source(from) or destination(to) feature; must not be DATA_ROW_ID_VOID.
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_relationship array of relationships read from the database (in case of success)
- *  \param[out] out_relationship_count number of relationship records stored in out_relationship
+ *  \param feature_id id of the source(from) or destination(to) feature; must not be DATA_ROW_VOID.
+ *  \param[in,out] io_relationship_iterator iterator over relationships of selected feature. The caller is responsible
+ *                                          for initializing before and destroying this object afterwards.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
+ *          U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_relationships_by_feature_id ( data_database_classifier_reader_t *this_,
-                                                                             data_row_id_t feature_id,
-                                                                             uint32_t max_out_array_size,
-                                                                             data_relationship_t (*out_relationship)[],
-                                                                             uint32_t *out_relationship_count
+                                                                             data_row_t feature_id,
+                                                                             data_relationship_iterator_t *io_relationship_iterator
                                                                            );
 
 /*!
@@ -300,18 +275,14 @@ u8_error_t data_database_classifier_reader_get_relationships_by_feature_id ( dat
  *
  *  \param this_ pointer to own object attributes
  *  \param diagram_id id of the containing diagram
- *  \param max_out_array_size size of the array where to store the results. If size is too small for the actual result set, this is an error.
- *  \param[out] out_relationship array of relationships read from the database (in case of success)
- *  \param[out] out_relationship_count number of relationship records stored in out_relationship
+ *  \param[in,out] io_relationship_iterator iterator over relationships of selected diagram. The caller is responsible
+ *                                          for initializing before and destroying this object afterwards.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- *          U8_ERROR_NO_DB if the database is not open,
- *          U8_ERROR_ARRAY_BUFFER_EXCEEDED if the provided out buffers are too small.
+ *          U8_ERROR_NO_DB if the database is not open.
  */
 u8_error_t data_database_classifier_reader_get_relationships_by_diagram_id ( data_database_classifier_reader_t *this_,
-                                                                             data_row_id_t diagram_id,
-                                                                             uint32_t max_out_array_size,
-                                                                             data_relationship_t (*out_relationship)[],
-                                                                             uint32_t *out_relationship_count
+                                                                             data_row_t diagram_id,
+                                                                             data_relationship_iterator_t *io_relationship_iterator
                                                                            );
 
 /* ================================ private ================================ */
@@ -339,12 +310,12 @@ u8_error_t data_database_classifier_reader_private_close ( data_database_classif
  *
  *  \param this_ pointer to own object attributes
  *  \param statement_ptr pointer to a statement object
- *  \param id integer to bind to the prepared statement. DATA_ROW_ID_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
+ *  \param id integer to bind to the prepared statement. DATA_ROW_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 static inline u8_error_t data_database_classifier_reader_private_bind_id_to_statement ( data_database_classifier_reader_t *this_,
                                                                                         sqlite3_stmt *statement_ptr,
-                                                                                        data_row_id_t id
+                                                                                        data_row_t id
                                                                                       );
 
 /*!
@@ -354,14 +325,14 @@ static inline u8_error_t data_database_classifier_reader_private_bind_id_to_stat
  *
  *  \param this_ pointer to own object attributes
  *  \param statement_ptr pointer to a statement object
- *  \param id1 first integer to bind to the prepared statement. DATA_ROW_ID_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
- *  \param id2 second integer to bind to the prepared statement. DATA_ROW_ID_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
+ *  \param id1 first integer to bind to the prepared statement. DATA_ROW_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
+ *  \param id2 second integer to bind to the prepared statement. DATA_ROW_VOID does not work because VOID is mapped to NULL and cannot be selected by the = operator.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 static inline u8_error_t data_database_classifier_reader_private_bind_two_ids_to_statement ( data_database_classifier_reader_t *this_,
                                                                                              sqlite3_stmt *statement_ptr,
-                                                                                             data_row_id_t id1,
-                                                                                             data_row_id_t id2
+                                                                                             data_row_t id1,
+                                                                                             data_row_t id2
                                                                                            );
 
 /*!
@@ -385,7 +356,7 @@ static inline u8_error_t data_database_classifier_reader_private_bind_text_to_st
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
