@@ -14,13 +14,13 @@
 #include "storage/data_database_listener.h"
 #include "storage/data_database_listener_signal.h"
 #include "storage/data_database.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "u8/u8_error.h"
-#include "data_classifier.h"
+#include "entity/data_classifier.h"
 #include "set/data_visible_classifier.h"
 #include "set/data_small_set.h"
-#include "data_feature.h"
-#include "data_relationship.h"
+#include "entity/data_feature.h"
+#include "entity/data_relationship.h"
 #include "set/data_search_result.h"
 #include "set/data_search_result_list.h"
 #include "data_rules.h"
@@ -244,7 +244,7 @@ static inline u8_error_t data_database_text_search_private_bind_three_texts_to_s
 
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
