@@ -1,7 +1,7 @@
 /* File: data_database_writer.c; Copyright and License: see below */
 
 #include "storage/data_database_writer.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
 #include <sqlite3.h>
@@ -69,12 +69,12 @@ void data_database_writer_db_change_callback ( data_database_writer_t *this_, da
 
 u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_,
                                                  const data_diagram_t *diagram,
-                                                 data_row_id_t* out_new_id )
+                                                 data_row_t* out_new_id )
 {
     U8_TRACE_BEGIN();
     assert( NULL != diagram );
     u8_error_t result = U8_ERROR_NONE;
-    data_row_id_t new_id = DATA_ROW_ID_VOID;
+    data_row_t new_id = DATA_ROW_VOID;
 
     result |= data_database_sql_builder_build_create_diagram_command( &((*this_).sql_builder), diagram );
     char *sql_cmd = data_database_sql_builder_get_string_ptr( &((*this_).sql_builder) );
@@ -86,7 +86,7 @@ u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_,
     U8_LOG_EVENT_INT( "sqlite3_exec: INSERT INTO diagrams ... ->", new_id );  /* do not log confidential information, only id */
 
     /* notify listeners */
-    data_row_id_t parent_id;
+    data_row_t parent_id;
     parent_id = data_diagram_get_parent_row_id( diagram );
     data_change_notifier_emit_signal( data_database_get_notifier_ptr( (*this_).database ),
                                       DATA_CHANGE_EVENT_TYPE_CREATE,
@@ -105,19 +105,12 @@ u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_,
     return result;
 }
 
-u8_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_,
-                                                 data_row_id_t obj_id,
-                                                 data_diagram_t *out_old_diagram )
+u8_error_t data_database_writer_delete_diagram( data_database_writer_t *this_,
+                                                data_row_t obj_id,
+                                                data_diagram_t *out_old_diagram )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
-    bool object_still_referenced;
-    data_diagram_t referencing_diagram[1];
-    uint32_t referencing_diagram_count;
-    data_visible_classifier_t referencing_classifier[1];
-    uint32_t referencing_classifier_count;
-    u8_error_t reference_check_err;
-
     result |= data_database_transaction_begin ( (*this_).database );
 
     /* Note: out_old_diagram is NULL if old data shall not be returned */
@@ -127,25 +120,22 @@ u8_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_,
     }
 
     /* Note: This function fails if the diagram is still referenced. */
-    reference_check_err = data_database_reader_get_diagrams_by_parent_id ( (*this_).db_reader, obj_id, 1, &referencing_diagram, &referencing_diagram_count );
-    if ( ( 0 != referencing_diagram_count ) || u8_error_contains( reference_check_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
-    {
-        object_still_referenced = true;
-    }
-    else
-    {
-        reference_check_err = data_database_reader_get_classifiers_by_diagram_id ( (*this_).db_reader, obj_id, 1, &referencing_classifier, &referencing_classifier_count );
-        if ( ( 0 != referencing_classifier_count ) || u8_error_contains( reference_check_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
-        {
-            object_still_referenced = true;
-        }
-        else
-        {
-            object_still_referenced = false;
-        }
-    }
+    data_diagram_iterator_t diagram_iterator;
+    result |= data_diagram_iterator_init_empty( &diagram_iterator );
+    result |= data_database_reader_get_diagrams_by_parent_id( (*this_).db_reader, obj_id, &diagram_iterator );
+    const bool has_child_diagrams = data_diagram_iterator_has_next( &diagram_iterator );
+    result |= data_diagram_iterator_destroy( &diagram_iterator );
 
-    if ( object_still_referenced )
+    data_diagramelement_iterator_t diagramelement_iterator;
+    result |= data_diagramelement_iterator_init_empty( &diagramelement_iterator );
+    result |= data_database_reader_get_diagramelements_by_diagram_id( (*this_).db_reader,
+                                                                      obj_id,
+                                                                      &diagramelement_iterator
+                                                                    );
+    const bool has_elements = data_diagramelement_iterator_has_next( &diagramelement_iterator );
+    result |= data_diagramelement_iterator_destroy( &diagramelement_iterator );
+
+    if ( has_child_diagrams || has_elements )
     {
         result |= U8_ERROR_OBJECT_STILL_REFERENCED;
     }
@@ -171,7 +161,7 @@ u8_error_t data_database_writer_delete_diagram ( data_database_writer_t *this_,
 }
 
 u8_error_t data_database_writer_update_diagram_type ( data_database_writer_t *this_,
-                                                      data_row_id_t diagram_id,
+                                                      data_row_t diagram_id,
                                                       data_diagram_type_t new_diagram_type,
                                                       data_diagram_t *out_old_diagram )
 {
@@ -206,7 +196,7 @@ u8_error_t data_database_writer_update_diagram_type ( data_database_writer_t *th
 }
 
 u8_error_t data_database_writer_update_diagram_stereotype ( data_database_writer_t *this_,
-                                                            data_row_id_t diagram_id,
+                                                            data_row_t diagram_id,
                                                             const char* new_diagram_stereotype,
                                                             data_diagram_t *out_old_diagram )
 {
@@ -242,7 +232,7 @@ u8_error_t data_database_writer_update_diagram_stereotype ( data_database_writer
 }
 
 u8_error_t data_database_writer_update_diagram_name ( data_database_writer_t *this_,
-                                                      data_row_id_t diagram_id,
+                                                      data_row_t diagram_id,
                                                       const char* new_diagram_name,
                                                       data_diagram_t *out_old_diagram )
 {
@@ -278,7 +268,7 @@ u8_error_t data_database_writer_update_diagram_name ( data_database_writer_t *th
 }
 
 u8_error_t data_database_writer_update_diagram_description ( data_database_writer_t *this_,
-                                                             data_row_id_t diagram_id,
+                                                             data_row_t diagram_id,
                                                              const char* new_diagram_description,
                                                              data_diagram_t *out_old_diagram )
 {
@@ -314,7 +304,7 @@ u8_error_t data_database_writer_update_diagram_description ( data_database_write
 }
 
 u8_error_t data_database_writer_update_diagram_list_order ( data_database_writer_t *this_,
-                                                            data_row_id_t diagram_id,
+                                                            data_row_t diagram_id,
                                                             int32_t new_diagram_list_order,
                                                             data_diagram_t *out_old_diagram )
 {
@@ -349,8 +339,8 @@ u8_error_t data_database_writer_update_diagram_list_order ( data_database_writer
 }
 
 u8_error_t data_database_writer_update_diagram_parent_id ( data_database_writer_t *this_,
-                                                           data_row_id_t diagram_id,
-                                                           data_row_id_t new_diagram_parent_id,
+                                                           data_row_t diagram_id,
+                                                           data_row_t new_diagram_parent_id,
                                                            data_diagram_t *out_old_diagram )
 {
     U8_TRACE_BEGIN();
@@ -389,12 +379,12 @@ u8_error_t data_database_writer_update_diagram_parent_id ( data_database_writer_
 
 u8_error_t data_database_writer_create_classifier( data_database_writer_t *this_,
                                                    const data_classifier_t *classifier,
-                                                   data_row_id_t* out_new_id )
+                                                   data_row_t* out_new_id )
 {
     U8_TRACE_BEGIN();
     assert( NULL != classifier );
     u8_error_t result = U8_ERROR_NONE;
-    data_row_id_t new_id = DATA_ROW_ID_VOID;
+    data_row_t new_id = DATA_ROW_VOID;
 
     result |= data_database_sql_builder_build_create_classifier_command( &((*this_).sql_builder), classifier );
     char *sql_cmd = data_database_sql_builder_get_string_ptr( &((*this_).sql_builder) );
@@ -410,7 +400,7 @@ u8_error_t data_database_writer_create_classifier( data_database_writer_t *this_
                                       DATA_TABLE_CLASSIFIER,
                                       new_id,
                                       DATA_TABLE_VOID,  /* classifiers have no parent */
-                                      DATA_ROW_ID_VOID  /* classifiers have no parent */
+                                      DATA_ROW_VOID  /* classifiers have no parent */
                                     );
 
     if ( NULL != out_new_id )
@@ -423,19 +413,12 @@ u8_error_t data_database_writer_create_classifier( data_database_writer_t *this_
 }
 
 u8_error_t data_database_writer_delete_classifier( data_database_writer_t *this_,
-                                                   data_row_id_t obj_id,
+                                                   data_row_t obj_id,
                                                    data_classifier_t *out_old_classifier )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
     bool object_still_referenced;
-    data_diagram_t referencing_diagram[1];
-    uint32_t referencing_diagram_count;
-    data_feature_t referencing_feature[1];
-    uint32_t referencing_feature_count;
-    data_relationship_t referencing_relationship[1];
-    uint32_t referencing_relationship_count;
-    u8_error_t reference_check_err;
 
     result |= data_database_transaction_begin ( (*this_).database );
 
@@ -446,22 +429,35 @@ u8_error_t data_database_writer_delete_classifier( data_database_writer_t *this_
     }
 
     /* Note: This function fails if the classifier is still referenced. */
-    reference_check_err = data_database_reader_get_diagrams_by_classifier_id ( (*this_).db_reader, obj_id, 1, &referencing_diagram, &referencing_diagram_count );
-    if ( ( 0 != referencing_diagram_count ) || u8_error_contains( reference_check_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
+    data_diagram_iterator_t diagram_iterator;
+    result |= data_diagram_iterator_init_empty( &diagram_iterator );
+    result |= data_database_reader_get_diagrams_by_classifier_id ( (*this_).db_reader, obj_id, &diagram_iterator );
+    const bool has_occurrences = data_diagram_iterator_has_next( &diagram_iterator );
+    result |= data_diagram_iterator_destroy( &diagram_iterator );
+
+    if ( has_occurrences )
     {
         object_still_referenced = true;
     }
     else
     {
-        reference_check_err = data_database_reader_get_features_by_classifier_id ( (*this_).db_reader, obj_id, 1, &referencing_feature, &referencing_feature_count );
-        if ( ( 0 != referencing_feature_count ) || u8_error_contains( reference_check_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
+        data_feature_iterator_t feature_iterator;
+        result |= data_feature_iterator_init_empty( &feature_iterator );
+        result |= data_database_reader_get_features_by_classifier_id ( (*this_).db_reader, obj_id, &feature_iterator );
+        const bool has_next_feature = data_feature_iterator_has_next( &feature_iterator );
+        result |= data_feature_iterator_destroy( &feature_iterator );
+        if ( has_next_feature )
         {
             object_still_referenced = true;
         }
         else
         {
-            reference_check_err = data_database_reader_get_relationships_by_classifier_id ( (*this_).db_reader, obj_id, 1, &referencing_relationship, &referencing_relationship_count );
-            if ( ( 0 != referencing_relationship_count ) || u8_error_contains( reference_check_err, U8_ERROR_ARRAY_BUFFER_EXCEEDED ) )
+            data_relationship_iterator_t rel_iterator;
+            result |= data_relationship_iterator_init_empty( &rel_iterator );
+            result |= data_database_reader_get_relationships_by_classifier_id ( (*this_).db_reader, obj_id, &rel_iterator );
+            const bool has_next_rel = data_relationship_iterator_has_next( &rel_iterator );
+            result |= data_relationship_iterator_destroy( &rel_iterator );
+            if ( has_next_rel )
             {
                 object_still_referenced = true;
             }
@@ -498,7 +494,7 @@ u8_error_t data_database_writer_delete_classifier( data_database_writer_t *this_
 }
 
 u8_error_t data_database_writer_update_classifier_main_type ( data_database_writer_t *this_,
-                                                              data_row_id_t classifier_id,
+                                                              data_row_t classifier_id,
                                                               data_classifier_type_t new_classifier_main_type,
                                                               data_classifier_t *out_old_classifier )
 {
@@ -533,7 +529,7 @@ u8_error_t data_database_writer_update_classifier_main_type ( data_database_writ
 }
 
 u8_error_t data_database_writer_update_classifier_stereotype ( data_database_writer_t *this_,
-                                                               data_row_id_t classifier_id,
+                                                               data_row_t classifier_id,
                                                                const char* new_classifier_stereotype,
                                                                data_classifier_t *out_old_classifier )
 {
@@ -568,7 +564,7 @@ u8_error_t data_database_writer_update_classifier_stereotype ( data_database_wri
 }
 
 u8_error_t data_database_writer_update_classifier_name ( data_database_writer_t *this_,
-                                                         data_row_id_t classifier_id,
+                                                         data_row_t classifier_id,
                                                          const char* new_classifier_name,
                                                          data_classifier_t *out_old_classifier )
 {
@@ -603,7 +599,7 @@ u8_error_t data_database_writer_update_classifier_name ( data_database_writer_t
 }
 
 u8_error_t data_database_writer_update_classifier_description ( data_database_writer_t *this_,
-                                                                data_row_id_t classifier_id,
+                                                                data_row_t classifier_id,
                                                                 const char* new_classifier_description,
                                                                 data_classifier_t *out_old_classifier )
 {
@@ -638,7 +634,7 @@ u8_error_t data_database_writer_update_classifier_description ( data_database_wr
 }
 
 u8_error_t data_database_writer_update_classifier_x_order ( data_database_writer_t *this_,
-                                                            data_row_id_t classifier_id,
+                                                            data_row_t classifier_id,
                                                             int32_t new_classifier_x_order,
                                                             data_classifier_t *out_old_classifier )
 {
@@ -673,7 +669,7 @@ u8_error_t data_database_writer_update_classifier_x_order ( data_database_writer
 }
 
 u8_error_t data_database_writer_update_classifier_y_order ( data_database_writer_t *this_,
-                                                            data_row_id_t classifier_id,
+                                                            data_row_t classifier_id,
                                                             int32_t new_classifier_y_order,
                                                             data_classifier_t *out_old_classifier )
 {
@@ -708,7 +704,7 @@ u8_error_t data_database_writer_update_classifier_y_order ( data_database_writer
 }
 
 u8_error_t data_database_writer_update_classifier_list_order ( data_database_writer_t *this_,
-                                                               data_row_id_t classifier_id,
+                                                               data_row_t classifier_id,
                                                                int32_t new_classifier_list_order,
                                                                data_classifier_t *out_old_classifier )
 {
@@ -746,12 +742,12 @@ u8_error_t data_database_writer_update_classifier_list_order ( data_database_wri
 
 u8_error_t data_database_writer_create_diagramelement( data_database_writer_t *this_,
                                                        const data_diagramelement_t *diagramelement,
-                                                       data_row_id_t* out_new_id )
+                                                       data_row_t* out_new_id )
 {
     U8_TRACE_BEGIN();
     assert( NULL != diagramelement );
     u8_error_t result = U8_ERROR_NONE;
-    data_row_id_t new_id = DATA_ROW_ID_VOID;
+    data_row_t new_id = DATA_ROW_VOID;
 
     result |= data_database_sql_builder_build_create_diagramelement_command( &((*this_).sql_builder), diagramelement );
     char *sql_cmd = data_database_sql_builder_get_string_ptr( &((*this_).sql_builder) );
@@ -762,7 +758,7 @@ u8_error_t data_database_writer_create_diagramelement( data_database_writer_t *t
     U8_LOG_EVENT_INT( "sqlite3_exec: INSERT INTO diagramelements ... ->", new_id );  /* do not log confidential information, only id */
 
     /* notify listeners */
-    data_row_id_t diagram_id;
+    data_row_t diagram_id;
     diagram_id = data_diagramelement_get_diagram_row_id( diagramelement );
     data_change_notifier_emit_signal( data_database_get_notifier_ptr( (*this_).database ),
                                       DATA_CHANGE_EVENT_TYPE_CREATE,
@@ -782,7 +778,7 @@ u8_error_t data_database_writer_create_diagramelement( data_database_writer_t *t
 }
 
 u8_error_t data_database_writer_delete_diagramelement( data_database_writer_t *this_,
-                                                       data_row_id_t obj_id,
+                                                       data_row_t obj_id,
                                                        data_diagramelement_t *out_old_diagramelement )
 {
     U8_TRACE_BEGIN();
@@ -816,7 +812,7 @@ u8_error_t data_database_writer_delete_diagramelement( data_database_writer_t *t
 }
 
 u8_error_t data_database_writer_update_diagramelement_display_flags ( data_database_writer_t *this_,
-                                                                      data_row_id_t diagramelement_id,
+                                                                      data_row_t diagramelement_id,
                                                                       data_diagramelement_flag_t new_display_flags,
                                                                       data_diagramelement_t *out_old_diagramelement )
 {
@@ -851,8 +847,8 @@ u8_error_t data_database_writer_update_diagramelement_display_flags ( data_datab
 }
 
 u8_error_t data_database_writer_update_diagramelement_focused_feature_id ( data_database_writer_t *this_,
-                                                                           data_row_id_t diagramelement_id,
-                                                                           data_row_id_t new_focused_feature_id,
+                                                                           data_row_t diagramelement_id,
+                                                                           data_row_t new_focused_feature_id,
                                                                            data_diagramelement_t *out_old_diagramelement )
 {
     U8_TRACE_BEGIN();
@@ -887,12 +883,12 @@ u8_error_t data_database_writer_update_diagramelement_focused_feature_id ( data_
 
 /* ================================ FEATURE ================================ */
 
-u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_, const data_feature_t *feature, data_row_id_t* out_new_id )
+u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_, const data_feature_t *feature, data_row_t* out_new_id )
 {
     U8_TRACE_BEGIN();
     assert( NULL != feature );
     u8_error_t result = U8_ERROR_NONE;
-    data_row_id_t new_id = DATA_ROW_ID_VOID;
+    data_row_t new_id = DATA_ROW_VOID;
 
     result |= data_database_sql_builder_build_create_feature_command( &((*this_).sql_builder), feature );
     char *sql_cmd = data_database_sql_builder_get_string_ptr( &((*this_).sql_builder) );
@@ -903,7 +899,7 @@ u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_,
     U8_LOG_EVENT_INT( "sqlite3_exec: INSERT INTO features ... ->", new_id );  /* do not log confidential information, only id */
 
     /* notify listeners */
-    data_row_id_t classifier_id;
+    data_row_t classifier_id;
     classifier_id = data_feature_get_classifier_row_id( feature );
     data_change_notifier_emit_signal( data_database_get_notifier_ptr( (*this_).database ),
                                       DATA_CHANGE_EVENT_TYPE_CREATE,
@@ -922,7 +918,7 @@ u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_,
     return result;
 }
 
-u8_error_t data_database_writer_delete_feature ( data_database_writer_t *this_, data_row_id_t obj_id, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_delete_feature ( data_database_writer_t *this_, data_row_t obj_id, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -954,7 +950,7 @@ u8_error_t data_database_writer_delete_feature ( data_database_writer_t *this_,
     return result;
 }
 
-u8_error_t data_database_writer_update_feature_main_type ( data_database_writer_t *this_, data_row_id_t feature_id, data_feature_type_t new_feature_type, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_update_feature_main_type ( data_database_writer_t *this_, data_row_t feature_id, data_feature_type_t new_feature_type, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -986,7 +982,7 @@ u8_error_t data_database_writer_update_feature_main_type ( data_database_writer_
     return result;
 }
 
-u8_error_t data_database_writer_update_feature_key ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_key, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_update_feature_key ( data_database_writer_t *this_, data_row_t feature_id, const char* new_feature_key, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1018,7 +1014,7 @@ u8_error_t data_database_writer_update_feature_key ( data_database_writer_t *thi
     return result;
 }
 
-u8_error_t data_database_writer_update_feature_value ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_value, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_update_feature_value ( data_database_writer_t *this_, data_row_t feature_id, const char* new_feature_value, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1050,7 +1046,7 @@ u8_error_t data_database_writer_update_feature_value ( data_database_writer_t *t
     return result;
 }
 
-u8_error_t data_database_writer_update_feature_description ( data_database_writer_t *this_, data_row_id_t feature_id, const char* new_feature_description, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_update_feature_description ( data_database_writer_t *this_, data_row_t feature_id, const char* new_feature_description, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1082,7 +1078,7 @@ u8_error_t data_database_writer_update_feature_description ( data_database_write
     return result;
 }
 
-u8_error_t data_database_writer_update_feature_list_order ( data_database_writer_t *this_, data_row_id_t feature_id, int32_t new_feature_list_order, data_feature_t *out_old_feature )
+u8_error_t data_database_writer_update_feature_list_order ( data_database_writer_t *this_, data_row_t feature_id, int32_t new_feature_list_order, data_feature_t *out_old_feature )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1116,12 +1112,12 @@ u8_error_t data_database_writer_update_feature_list_order ( data_database_writer
 
 /* ================================ RELATIONSHIP ================================ */
 
-u8_error_t data_database_writer_create_relationship ( data_database_writer_t *this_, const data_relationship_t *relationship, data_row_id_t* out_new_id )
+u8_error_t data_database_writer_create_relationship ( data_database_writer_t *this_, const data_relationship_t *relationship, data_row_t* out_new_id )
 {
     U8_TRACE_BEGIN();
     assert( NULL != relationship );
     u8_error_t result = U8_ERROR_NONE;
-    data_row_id_t new_id = DATA_ROW_ID_VOID;
+    data_row_t new_id = DATA_ROW_VOID;
 
     result |= data_database_sql_builder_build_create_relationship_command( &((*this_).sql_builder), relationship );
     char *sql_cmd = data_database_sql_builder_get_string_ptr( &((*this_).sql_builder) );
@@ -1132,7 +1128,7 @@ u8_error_t data_database_writer_create_relationship ( data_database_writer_t *th
     U8_LOG_EVENT_INT( "sqlite3_exec: INSERT INTO relationships ... ->", new_id );  /* do not log confidential information, only id */
 
     /* notify listeners */
-    data_row_id_t from_classifier_id;
+    data_row_t from_classifier_id;
     from_classifier_id = data_relationship_get_from_classifier_row_id( relationship );
     data_change_notifier_emit_signal( data_database_get_notifier_ptr( (*this_).database ),
                                       DATA_CHANGE_EVENT_TYPE_CREATE,
@@ -1151,7 +1147,7 @@ u8_error_t data_database_writer_create_relationship ( data_database_writer_t *th
     return result;
 }
 
-u8_error_t data_database_writer_delete_relationship ( data_database_writer_t *this_, data_row_id_t obj_id, data_relationship_t *out_old_relationship )
+u8_error_t data_database_writer_delete_relationship ( data_database_writer_t *this_, data_row_t obj_id, data_relationship_t *out_old_relationship )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1184,7 +1180,7 @@ u8_error_t data_database_writer_delete_relationship ( data_database_writer_t *th
 }
 
 u8_error_t data_database_writer_update_relationship_main_type ( data_database_writer_t *this_,
-                                                                data_row_id_t relationship_id,
+                                                                data_row_t relationship_id,
                                                                 data_relationship_type_t new_relationship_type,
                                                                 data_relationship_t *out_old_relationship )
 {
@@ -1219,7 +1215,7 @@ u8_error_t data_database_writer_update_relationship_main_type ( data_database_wr
 }
 
 u8_error_t data_database_writer_update_relationship_stereotype ( data_database_writer_t *this_,
-                                                                 data_row_id_t relationship_id,
+                                                                 data_row_t relationship_id,
                                                                  const char* new_relationship_stereotype,
                                                                  data_relationship_t *out_old_relationship )
 {
@@ -1254,7 +1250,7 @@ u8_error_t data_database_writer_update_relationship_stereotype ( data_database_w
 }
 
 u8_error_t data_database_writer_update_relationship_name ( data_database_writer_t *this_,
-                                                           data_row_id_t relationship_id,
+                                                           data_row_t relationship_id,
                                                            const char* new_relationship_name,
                                                            data_relationship_t *out_old_relationship )
 {
@@ -1288,7 +1284,7 @@ u8_error_t data_database_writer_update_relationship_name ( data_database_writer_
     return result;
 }
 
-u8_error_t data_database_writer_update_relationship_description ( data_database_writer_t *this_, data_row_id_t relationship_id, const char* new_relationship_description, data_relationship_t *out_old_relationship )
+u8_error_t data_database_writer_update_relationship_description ( data_database_writer_t *this_, data_row_t relationship_id, const char* new_relationship_description, data_relationship_t *out_old_relationship )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1320,7 +1316,7 @@ u8_error_t data_database_writer_update_relationship_description ( data_database_
     return result;
 }
 
-u8_error_t data_database_writer_update_relationship_list_order ( data_database_writer_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order, data_relationship_t *out_old_relationship )
+u8_error_t data_database_writer_update_relationship_list_order ( data_database_writer_t *this_, data_row_t relationship_id, int32_t new_relationship_list_order, data_relationship_t *out_old_relationship )
 {
     U8_TRACE_BEGIN();
     u8_error_t result = U8_ERROR_NONE;
@@ -1354,7 +1350,7 @@ u8_error_t data_database_writer_update_relationship_list_order ( data_database_w
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
