@@ -34,7 +34,7 @@
 #include "set/data_search_result_list.h"
 #include "ctrl_controller.h"
 #include "pencil_diagram_maker.h"
-#include <gtk/gtk.h>
+#include "gui_gtk.h"
 #include <stdbool.h>
 #include <stdint.h>
 
