@@ -9,7 +9,7 @@
  */
 
 #include "gui_attributes_editor.h"
-#include "data_classifier_type.h"
+#include "entity/data_classifier_type.h"
 
 /*!
  *  \brief attributes of the gui_attribute_type_of_classifier_t
@@ -62,7 +62,7 @@ static inline gui_attributes_editor_t* gui_attribute_type_of_classifier_get_edit
 
 
 /*
-Copyright 2023-2024 Andreas Warnke
+Copyright 2023-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
