@@ -7,7 +7,7 @@
 #include "meta/meta_info.h"
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
-#include <gtk/gtk.h>
+#include "gui_gtk.h"
 #include <stdio.h>
 #include <stdlib.h>
 
