@@ -60,7 +60,7 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
         gui_simple_message_to_user_hide( (*this_).message_to_user );
 
         data_search_result_list_clear( &((*this_).temp_result_list) );
-        const data_row_id_t search_row_id = data_id_get_row_id(&search_id);
+        const data_row_t search_row_id = data_id_get_row_id(&search_id);
         u8_error_t d_err = U8_ERROR_NONE;
 
         if ( data_id_is_valid( &search_id ))
@@ -80,7 +80,7 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
                                                             search_row_id,
                                                             data_classifier_get_main_type( &((*this_).temp_classifier) ),
                                                             data_classifier_get_name_const( &((*this_).temp_classifier) ),
-                                                            DATA_ROW_ID_VOID /* diagram_id */
+                                                            DATA_ROW_VOID /* diagram_id */
                                                         );
                         gui_search_runner_private_add_diagrams_of_classifier( this_, &half_initialized, &((*this_).temp_result_list) );
 
@@ -102,14 +102,14 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
                                                                    );
                     if ( d_err == U8_ERROR_NONE )
                     {
-                        data_row_id_t classifier_id = data_feature_get_classifier_row_id( &((*this_).temp_feature) );
+                        data_row_t classifier_id = data_feature_get_classifier_row_id( &((*this_).temp_feature) );
                         data_search_result_t half_initialized;
                         data_search_result_init_feature( &half_initialized,
                                                          data_feature_get_row_id( &((*this_).temp_feature) ),
                                                          data_feature_get_main_type( &((*this_).temp_feature) ),
                                                          data_feature_get_key_const( &((*this_).temp_feature) ),
                                                          classifier_id,
-                                                         DATA_ROW_ID_VOID /* diagram_id */
+                                                         DATA_ROW_VOID /* diagram_id */
                                                        );
                         gui_search_runner_private_add_diagrams_of_classifier( this_, &half_initialized, &((*this_).temp_result_list) );
 
@@ -131,7 +131,7 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
                                                                         );
                     if ( d_err == U8_ERROR_NONE )
                     {
-                        data_row_id_t classifier_id = data_relationship_get_from_classifier_row_id( &((*this_).temp_relationship) );
+                        data_row_t classifier_id = data_relationship_get_from_classifier_row_id( &((*this_).temp_relationship) );
                         data_search_result_t half_initialized;
                         data_search_result_init_relationship( &half_initialized,
                                                               data_relationship_get_row_id( &((*this_).temp_relationship) ),
@@ -139,7 +139,7 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
                                                               data_relationship_get_name_const( &((*this_).temp_relationship) ),
                                                               classifier_id,
                                                               data_relationship_get_to_classifier_row_id( &((*this_).temp_relationship) ),
-                                                              DATA_ROW_ID_VOID /* diagram_id */
+                                                              DATA_ROW_VOID /* diagram_id */
                                                             );
                         gui_search_runner_private_add_diagrams_of_classifier( this_, &half_initialized, &((*this_).temp_result_list) );
 
@@ -187,15 +187,14 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
 
                 case DATA_TABLE_DIAGRAM:
                 {
-                    assert( GUI_SEARCH_RUNNER_MAX_DIAGRAMS > 0 );
-                    d_err = data_database_reader_get_diagram_by_id ( (*this_).db_reader, search_row_id, &((*this_).temp_diagrams[0]) );
+                    d_err = data_database_reader_get_diagram_by_id ( (*this_).db_reader, search_row_id, &((*this_).temp_diagram) );
                     if ( d_err == U8_ERROR_NONE )
                     {
                         data_search_result_t half_initialized;
                         data_search_result_init_diagram( &half_initialized,
                                                          search_row_id,
-                                                         data_diagram_get_diagram_type( &((*this_).temp_diagrams[0]) ),
-                                                         data_diagram_get_name_const( &((*this_).temp_diagrams[0]) )
+                                                         data_diagram_get_diagram_type( &((*this_).temp_diagram) ),
+                                                         data_diagram_get_name_const( &((*this_).temp_diagram) )
                                                        );
                         const u8_error_t err = data_search_result_list_add( &((*this_).temp_result_list), &half_initialized );
                         if ( err != U8_ERROR_NONE )
@@ -204,7 +203,7 @@ void gui_search_runner_run ( gui_search_runner_t *this_, const char* search_stri
                             U8_LOG_WARNING( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at inserting search result to list" );
                         }
 
-                        data_diagram_destroy( &((*this_).temp_diagrams[0]) );
+                        data_diagram_destroy( &((*this_).temp_diagram) );
                         data_search_result_destroy( &half_initialized );
                     }
                     else
@@ -257,7 +256,7 @@ void gui_search_runner_private_add_diagrams_of_classifier ( gui_search_runner_t
     assert( io_list != NULL );
     u8_error_t d_err = U8_ERROR_NONE;
 
-    data_row_id_t classifier_row_id;
+    data_row_t classifier_row_id;
     if ( DATA_TABLE_CLASSIFIER == data_id_get_table( data_search_result_get_match_id_const( classifier_template )))
     {
         classifier_row_id = data_id_get_row_id( data_search_result_get_match_id_const( classifier_template ));
@@ -266,24 +265,20 @@ void gui_search_runner_private_add_diagrams_of_classifier ( gui_search_runner_t
     {
         classifier_row_id = data_id_get_row_id( data_search_result_get_src_classifier_id_const( classifier_template ));
     }
-    uint32_t diagram_count;
-    d_err = data_database_reader_get_diagrams_by_classifier_id ( (*this_).db_reader,
-                                                                 classifier_row_id,
-                                                                 GUI_SEARCH_RUNNER_MAX_DIAGRAMS,
-                                                                 &((*this_).temp_diagrams),
-                                                                 &diagram_count
-                                                               );
-    if ( d_err == U8_ERROR_ARRAY_BUFFER_EXCEEDED )
-    {
-        U8_LOG_WARNING( "U8_ERROR_ARRAY_BUFFER_EXCEEDED at searching diagrams" );
-    }
 
-    if (( d_err == U8_ERROR_NONE )||( d_err == U8_ERROR_ARRAY_BUFFER_EXCEEDED ))
+    data_diagram_iterator_t diagram_iterator;
+    d_err |= data_diagram_iterator_init_empty( &diagram_iterator );
+    d_err |= data_database_reader_get_diagrams_by_classifier_id( (*this_).db_reader,
+                                                                classifier_row_id,
+                                                                &diagram_iterator
+                                                              );
+
+    if ( d_err == U8_ERROR_NONE )
     {
-        assert ( diagram_count <= GUI_SEARCH_RUNNER_MAX_DIAGRAMS );
-        for ( uint32_t idx = 0; idx < diagram_count; idx ++ )
+        while ( data_diagram_iterator_has_next( &diagram_iterator ) )
         {
-            const data_row_id_t diagram_row_id = data_diagram_get_row_id ( &((*this_).temp_diagrams[idx]) );
+            d_err |= data_diagram_iterator_next( &diagram_iterator, &((*this_).temp_diagram) );
+            const data_row_t diagram_row_id = data_diagram_get_row_id( &((*this_).temp_diagram) );
             data_id_reinit( data_search_result_get_diagram_id_ptr( classifier_template ), DATA_TABLE_DIAGRAM, diagram_row_id );
 
             bool filter = false;
@@ -320,20 +315,21 @@ void gui_search_runner_private_add_diagrams_of_classifier ( gui_search_runner_t
                 }
             }
 
-            data_diagram_destroy( &((*this_).temp_diagrams[idx]) );
+            data_diagram_destroy( &((*this_).temp_diagram) );
         }
     }
     else
     {
         U8_TRACE_INFO( "diagram does not exist or database not open." );
     }
+    d_err |= data_diagram_iterator_destroy( &diagram_iterator );
 
     U8_TRACE_END();
 }
 
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
