@@ -11,7 +11,7 @@
 #include "sketch/gui_sketch_card.h"
 #include "gui_tool.h"
 #include "shape/shape_int_rectangle.h"
-#include <gtk/gtk.h>
+#include "gui_gtk.h"
 #include <stdbool.h>
 #include <stdint.h>
 
