@@ -23,8 +23,8 @@
 #include "format/io_txt_icon.h"
 #include "format/io_md_writer.h"
 #include "json/json_type_name_map.h"
-#include "data_diagram.h"
-#include "data_classifier.h"
+#include "entity/data_diagram.h"
+#include "entity/data_classifier.h"
 #include "data_rules.h"
 #include "set/data_visible_set.h"
 #include "set/data_stat.h"
@@ -422,7 +422,7 @@ u8_error_t document_element_writer_write_footer( document_element_writer_t *this
 
 
 /*
-Copyright 2019-2024 Andreas Warnke
+Copyright 2019-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
