@@ -10,9 +10,9 @@
  */
 
 #include "json/json_constants.h"
-#include "data_diagram.h"
-#include "data_classifier.h"
-#include "data_table.h"
+#include "entity/data_diagram.h"
+#include "entity/data_classifier.h"
+#include "entity/data_table.h"
 #include "utf8stringbuf/utf8string.h"
 #include "utf8stringbuf/utf8stringview.h"
 #include "u8stream/universal_output_stream.h"
@@ -202,7 +202,7 @@ static inline u8_error_t json_writer_write_member_string_array ( json_writer_t *
 
 
 /*
-Copyright 2021-2024 Andreas Warnke
+Copyright 2021-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
