@@ -11,9 +11,9 @@
 
 #include "xmi/xmi_spec.h"
 #include "xmi/xmi_element_info.h"
-#include "data_classifier_type.h"
-#include "data_feature_type.h"
-#include "data_relationship_type.h"
+#include "entity/data_classifier_type.h"
+#include "entity/data_feature_type.h"
+#include "entity/data_relationship_type.h"
 #include "u8/u8_error.h"
 #include <stdbool.h>
 
@@ -154,7 +154,7 @@ static inline int xmi_element_info_map_get_relationship ( const xmi_element_info
 
 
 /*
-Copyright 2020-2024 Andreas Warnke
+Copyright 2020-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
