@@ -5,8 +5,8 @@
 #include "io_file_format.h"
 #include "io_importer.h"
 #include "io_import_mode.h"
-#include "data_head.h"
-#include "data_head_key.h"
+#include "entity/data_head.h"
+#include "entity/data_head_key.h"
 #include "storage/data_database_head.h"
 #include "u8dir/u8dir_file.h"
 #include "u8stream/universal_file_input_stream.h"
@@ -18,7 +18,6 @@
 
 static const char *IO_DATA_FILE_TEMP_EXT = ".tmp-cfu";
 static const char *IO_DATA_FILE_JSON_EXT = ".cfuJ";
-static const char *IO_DATA_FILE_CFU1_EXT = ".cfu1";  /* the native sqlite3 DB format */
 
 void io_data_file_init ( io_data_file_t *this_ )
 {
@@ -28,15 +27,16 @@ void io_data_file_init ( io_data_file_t *this_ )
     ctrl_controller_init( &((*this_).controller), &((*this_).database) );
 
     (*this_).data_file_name
-        = utf8stringbuf_init( sizeof((*this_).private_data_file_name_buffer), (*this_).private_data_file_name_buffer );
-    utf8stringbuf_clear( (*this_).data_file_name );
+        = utf8stringbuf_new( (*this_).private_data_file_name_buffer, sizeof((*this_).private_data_file_name_buffer) );
+    utf8stringbuf_clear( &((*this_).data_file_name) );
 
     (*this_).db_file_name
-        = utf8stringbuf_init( sizeof((*this_).private_db_file_name_buffer), (*this_).private_db_file_name_buffer );
-    utf8stringbuf_clear( (*this_).db_file_name );
+        = utf8stringbuf_new( (*this_).private_db_file_name_buffer, sizeof((*this_).private_db_file_name_buffer) );
+    utf8stringbuf_clear( &((*this_).db_file_name) );
 
     (*this_).auto_writeback_to_json = false;
     (*this_).delete_db_when_finished = false;
+    (*this_).sync_revision = 0;
 
     U8_TRACE_END();
 }
@@ -75,7 +75,7 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
 
     if ( file_not_readable != U8_ERROR_NONE )
     {
-        if ( temp_requested )
+        if (( temp_requested )||( ! is_json ))
         {
             U8_TRACE_INFO( "CASE: use temp db file that does not exist, is not accessible or has wrong format" );
             U8_TRACE_INFO( read_only ? "read_only" : "writeable" );
@@ -83,33 +83,25 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             /* To be consistent with the case of opening an existing temporary file, also this is exported to json later */
             (*this_).auto_writeback_to_json = ( ! read_only );
             (*this_).delete_db_when_finished = ( ! read_only );
-            err |= utf8stringbuf_copy_view( (*this_).data_file_name, &req_file_parent );
-            err |= utf8stringbuf_append_view( (*this_).data_file_name, &req_file_basename );
-            err |= utf8stringbuf_append_str( (*this_).data_file_name, IO_DATA_FILE_JSON_EXT );
-            err |= utf8stringbuf_copy_str( (*this_).db_file_name, requested_file_path );
+
+            err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
+            err |= utf8stringbuf_append_view( &((*this_).data_file_name), &req_file_basename );
+            err |= utf8stringbuf_append_str( &((*this_).data_file_name), IO_DATA_FILE_JSON_EXT );
+
+            err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
         }
-        else if ( is_json )
+        else
         {
             U8_TRACE_INFO( "CASE: use json file that does not exist or is not accessible" );
             U8_TRACE_INFO( read_only ? "read_only" : "writeable" );
             /* A new json file shall be created */
             (*this_).auto_writeback_to_json = ( ! read_only );
             (*this_).delete_db_when_finished = ( ! read_only );
-            err |= utf8stringbuf_copy_str( (*this_).data_file_name, requested_file_path );
-            err |= utf8stringbuf_copy_view( (*this_).db_file_name, &req_file_parent );
-            err |= utf8stringbuf_append_view( (*this_).db_file_name, &req_file_basename );
-            err |= utf8stringbuf_append_str( (*this_).db_file_name, IO_DATA_FILE_TEMP_EXT );
-            u8dir_file_remove( utf8stringbuf_get_string( (*this_).db_file_name ) );  /* ignore possible errors */
-        }
-        else
-        {
-            U8_TRACE_INFO( "CASE: use sqlite file that does not exist, is not accessible or has wrong format" );
-            U8_TRACE_INFO( read_only ? "read_only" : "writeable" );
-            /* A new sqlite file shall be created */
-            (*this_).auto_writeback_to_json = false;
-            (*this_).delete_db_when_finished = false;
-            err |= utf8stringbuf_copy_str( (*this_).data_file_name, requested_file_path );
-            err |= utf8stringbuf_copy_str( (*this_).db_file_name, requested_file_path );
+            err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
+            err |= utf8stringbuf_copy_view( &((*this_).db_file_name), &req_file_parent );
+            err |= utf8stringbuf_append_view( &((*this_).db_file_name), &req_file_basename );
+            err |= utf8stringbuf_append_str( &((*this_).db_file_name), IO_DATA_FILE_TEMP_EXT );
+            u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible errors */
         }
     }
     else
@@ -120,10 +112,10 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             /* A temporary sqlite file shall be used and later be exported to json */
             (*this_).auto_writeback_to_json = ( ! read_only );
             (*this_).delete_db_when_finished = ( ! read_only );
-            err |= utf8stringbuf_copy_view( (*this_).data_file_name, &req_file_parent );
-            err |= utf8stringbuf_append_view( (*this_).data_file_name, &req_file_basename );
-            err |= utf8stringbuf_append_str( (*this_).data_file_name, IO_DATA_FILE_JSON_EXT );
-            err |= utf8stringbuf_copy_str( (*this_).db_file_name, requested_file_path );
+            err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
+            err |= utf8stringbuf_append_view( &((*this_).data_file_name), &req_file_basename );
+            err |= utf8stringbuf_append_str( &((*this_).data_file_name), IO_DATA_FILE_JSON_EXT );
+            err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
         }
         else if ( is_json )
         {
@@ -131,13 +123,13 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             /* An existing json file shall be used */
             (*this_).auto_writeback_to_json = ( ! read_only );
             (*this_).delete_db_when_finished = true;
-            err |= utf8stringbuf_copy_str( (*this_).data_file_name, requested_file_path );
-            err |= utf8stringbuf_copy_view( (*this_).db_file_name, &req_file_parent );
-            err |= utf8stringbuf_append_view( (*this_).db_file_name, &req_file_basename );
-            err |= utf8stringbuf_append_str( (*this_).db_file_name, IO_DATA_FILE_TEMP_EXT );
-            u8dir_file_remove( utf8stringbuf_get_string( (*this_).db_file_name ) );  /* ignore possible errors */
+            err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
+            err |= utf8stringbuf_copy_view( &((*this_).db_file_name), &req_file_parent );
+            err |= utf8stringbuf_append_view( &((*this_).db_file_name), &req_file_basename );
+            err |= utf8stringbuf_append_str( &((*this_).db_file_name), IO_DATA_FILE_TEMP_EXT );
+            u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible errors */
 
-            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( (*this_).db_file_name ) );
+            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
             if ( err != U8_ERROR_NONE )
             {
                 U8_LOG_ERROR("An error occurred at creating a temporary database file, possibly the parent directory is read-only.")
@@ -147,13 +139,13 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             }
             else
             {
-                err |= io_data_file_private_import( this_, utf8stringbuf_get_string( (*this_).data_file_name ), out_err_info );
+                err |= io_data_file_private_import( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ), out_err_info );
                 err |= data_database_close( &((*this_).database) );
 
                 if ( err != U8_ERROR_NONE )
                 {
                     U8_LOG_ERROR("An error occurred at reading a json data file")
-                    u8dir_file_remove( utf8stringbuf_get_string( (*this_).db_file_name ) );  /* ignore possible additional errors */
+                    u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible additional errors */
                     U8_LOG_WARNING("Changes will not be written back to not accidentally overwrite the data source")
                     (*this_).auto_writeback_to_json = false;
                     (*this_).delete_db_when_finished = true;  /* do not keep .tmp-cfu files when import was not successful */
@@ -166,22 +158,22 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             /* An sqlite file shall be used */
             (*this_).auto_writeback_to_json = false;
             (*this_).delete_db_when_finished = false;
-            err |= utf8stringbuf_copy_str( (*this_).data_file_name, requested_file_path );
-            err |= utf8stringbuf_copy_str( (*this_).db_file_name, requested_file_path );
+            err |= utf8stringbuf_copy_str( &((*this_).data_file_name), requested_file_path );
+            err |= utf8stringbuf_copy_str( &((*this_).db_file_name), requested_file_path );
         }
     }
-    U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( (*this_).data_file_name ) );
-    U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( (*this_).db_file_name ) );
+    U8_TRACE_INFO_STR( "data_file_name:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
+    U8_TRACE_INFO_STR( "db_file_name:  ", utf8stringbuf_get_string( &((*this_).db_file_name) ) );
 
     if ( err == U8_ERROR_NONE )
     {
         if ( read_only )
         {
-            err |= data_database_open_read_only( &((*this_).database), utf8stringbuf_get_string( (*this_).db_file_name ) );
+            err |= data_database_open_read_only( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
         }
         else
         {
-            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( (*this_).db_file_name ) );
+            err |= data_database_open( &((*this_).database), utf8stringbuf_get_string( &((*this_).db_file_name) ) );
         }
     }
 
@@ -197,8 +189,8 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
         {
             U8_TRACE_INFO_STR( "DATA_FILE_NAME:", data_head_get_value_const( &head ) );
             /* set the data_file_name to the read head value */
-            err |= utf8stringbuf_copy_view( (*this_).data_file_name, &req_file_parent );
-            err |= utf8stringbuf_append_str( (*this_).data_file_name, data_head_get_value_const( &head ) );
+            err |= utf8stringbuf_copy_view( &((*this_).data_file_name), &req_file_parent );
+            err |= utf8stringbuf_append_str( &((*this_).data_file_name), data_head_get_value_const( &head ) );
         }
         else if ( (*this_).auto_writeback_to_json )
         {
@@ -207,6 +199,8 @@ u8_error_t io_data_file_open ( io_data_file_t *this_,
             err |= data_database_head_create_value( &head_table, &head, NULL );
         }
         data_database_head_destroy( &head_table );
+
+        (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
     }
 
     U8_TRACE_END_ERR( err );
@@ -222,7 +216,7 @@ u8_error_t io_data_file_close ( io_data_file_t *this_ )
     if ( (*this_).auto_writeback_to_json )
     {
         U8_TRACE_INFO( "CASE: auto_writeback_to_json == true" );
-        result |= io_data_file_private_export( this_, utf8stringbuf_get_string( (*this_).data_file_name ) );
+        result |= io_data_file_private_export( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ) );
     }
 
     result |= data_database_close( &((*this_).database) );
@@ -230,7 +224,7 @@ u8_error_t io_data_file_close ( io_data_file_t *this_ )
     if ( (*this_).delete_db_when_finished )
     {
         U8_TRACE_INFO( "CASE: delete_db_when_finished == true" );
-        u8dir_file_remove( utf8stringbuf_get_string( (*this_).db_file_name ) );  /* ignore possible errors */
+        u8dir_file_remove( utf8stringbuf_get_string( &((*this_).db_file_name) ) );  /* ignore possible errors */
     }
 
     (*this_).auto_writeback_to_json = false;
@@ -248,7 +242,7 @@ u8_error_t io_data_file_sync_to_disk ( io_data_file_t *this_ )
 
     if ( (*this_).auto_writeback_to_json )
     {
-        result |= io_data_file_private_export( this_, utf8stringbuf_get_string( (*this_).data_file_name ) );
+        result |= io_data_file_private_export( this_, utf8stringbuf_get_string( &((*this_).data_file_name) ) );
     }
 
     U8_TRACE_END_ERR( result );
@@ -259,7 +253,7 @@ u8_error_t io_data_file_trace_stats ( io_data_file_t *this_ )
 {
     U8_TRACE_BEGIN();
 
-    U8_TRACE_INFO_STR( "io_data_file_t:", utf8stringbuf_get_string( (*this_).data_file_name ) );
+    U8_TRACE_INFO_STR( "io_data_file_t:", utf8stringbuf_get_string( &((*this_).data_file_name) ) );
 
     const u8_error_t result = data_database_trace_stats( &((*this_).database) );
 
@@ -303,16 +297,8 @@ u8_error_t io_data_file_private_guess_db_type ( const io_data_file_t *this_, con
     }
     else
     {
-        if( 1 == utf8string_ends_with_str( filename, IO_DATA_FILE_CFU1_EXT ) )
-        {
-            U8_TRACE_INFO_STR("File does not exist and type defaults to sqlite3:", filename);
-            *out_json = false;
-        }
-        else
-        {
-            U8_TRACE_INFO_STR("File does not exist and is of type json:", filename);
-            *out_json = true;
-        }
+        U8_TRACE_INFO_STR("File does not exist", filename);
+        *out_json = true;
     }
 
     /* cleanup */
@@ -386,6 +372,8 @@ u8_error_t io_data_file_private_export ( io_data_file_t *this_, const char *dst_
         }
         io_exporter_destroy( &exporter );
         data_database_reader_destroy( &db_reader );
+
+        (*this_).sync_revision = data_database_get_revision( &((*this_).database) );
     }
     else
     {
@@ -398,7 +386,7 @@ u8_error_t io_data_file_private_export ( io_data_file_t *this_, const char *dst_
 
 
 /*
-Copyright 2022-2024 Andreas Warnke
+Copyright 2022-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
