@@ -21,7 +21,7 @@ static test_case_result_t test_reject_duplicates( test_fixture_t *fix );
 /*!
  *  \brief helper function creates a root diagram and sets the element importer to paste mode
  */
-static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix );
+static data_row_t set_mode_paste_to_root_diag( test_fixture_t *fix );
 
 test_suite_t io_import_elements_test_get_suite(void)
 {
@@ -84,7 +84,7 @@ static void tear_down( test_fixture_t *fix )
     data_database_destroy( &((*fix).database) );
 }
 
-static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix )
+static data_row_t set_mode_paste_to_root_diag( test_fixture_t *fix )
 {
     u8_error_t ctrl_err;
     u8_error_t data_err;
@@ -93,12 +93,12 @@ static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix )
     diagram_ctrl = ctrl_controller_get_diagram_control_ptr( &((*fix).controller) );
 
     /* create a diagram */
-    data_row_id_t root_diag_id;
+    data_row_t root_diag_id;
 
     data_diagram_t root_diagram;
     data_err = data_diagram_init( &root_diagram,
-                                  DATA_ROW_ID_VOID,  /* diagram_id */
-                                  DATA_ROW_ID_VOID,  /* parent_diagram_id */
+                                  DATA_ROW_VOID,  /* diagram_id */
+                                  DATA_ROW_VOID,  /* parent_diagram_id */
                                   DATA_DIAGRAM_TYPE_UML_CLASS_DIAGRAM,
                                   "stereo_t",  /* stereotype */
                                   "Th& <root> d\"agram",
@@ -109,14 +109,14 @@ static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix )
                                 );
     TEST_ENVIRONMENT_ASSERT( U8_ERROR_NONE == data_err );
 
-    root_diag_id = DATA_ROW_ID_VOID;
+    root_diag_id = DATA_ROW_VOID;
     ctrl_err = ctrl_diagram_controller_create_diagram ( diagram_ctrl,
                                                         &root_diagram,
                                                         CTRL_UNDO_REDO_ACTION_BOUNDARY_START_NEW,
                                                         &root_diag_id
                                                       );
     TEST_ENVIRONMENT_ASSERT( U8_ERROR_NONE == ctrl_err );
-    TEST_ENVIRONMENT_ASSERT( DATA_ROW_ID_VOID != root_diag_id );
+    TEST_ENVIRONMENT_ASSERT( DATA_ROW_VOID != root_diag_id );
     data_diagram_destroy ( &root_diagram );
 
     io_import_elements_destroy( &((*fix).elements_importer) );
@@ -129,7 +129,7 @@ static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix )
 static test_case_result_t test_reject_duplicates( test_fixture_t *fix )
 {
     assert( fix != NULL );
-    data_row_id_t root_diag_id = set_mode_paste_to_root_diag( fix );
+    data_row_t root_diag_id = set_mode_paste_to_root_diag( fix );
     TEST_ENVIRONMENT_ASSERT( 1 == root_diag_id );
     u8_error_t err;
 
@@ -213,7 +213,7 @@ static test_case_result_t test_reject_duplicates( test_fixture_t *fix )
 
 
 /*
- * Copyright 2021-2024 Andreas Warnke
+ * Copyright 2021-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
