@@ -57,33 +57,6 @@ void main_commands_destroy ( main_commands_t *this_ )
     U8_TRACE_END();
 }
 
-u8_error_t main_commands_upgrade ( main_commands_t *this_,
-                                   const char *data_file_path,
-                                   utf8stream_writer_t *out_english_report )
-{
-    U8_TRACE_BEGIN();
-    u8_error_t result = U8_ERROR_NONE;
-
-    assert( data_file_path != NULL );
-
-    U8_TRACE_INFO("opening DB...");
-    u8_error_info_t err_info;
-    result |= io_data_file_open_writeable( (*this_).data_file, data_file_path, &err_info );  /* upgrade is implicitely done */
-    if ( result != U8_ERROR_NONE )
-    {
-        utf8stream_writer_write_str( out_english_report, "error opening database_file " );
-        utf8stream_writer_write_str( out_english_report, data_file_path );
-        utf8stream_writer_write_str( out_english_report, "\n" );
-    }
-    result |= main_commands_private_report_error_info( this_, &err_info, out_english_report );
-
-    U8_TRACE_INFO("closing DB...");
-    io_data_file_close( (*this_).data_file );
-
-    U8_TRACE_END_ERR( result );
-    return result;
-}
-
 u8_error_t main_commands_repair ( main_commands_t *this_,
                                   const char *data_file_path,
                                   bool check_only,
@@ -373,14 +346,14 @@ u8_error_t main_commands_private_report_error_info ( main_commands_t *this_,
     {
         char info_string_buf[80];
         utf8stringbuf_t info_string = UTF8STRINGBUF(info_string_buf);
-        utf8stringbuf_clear( info_string );
+        utf8stringbuf_clear( &info_string );
         {
             gui_error_info_printer_t my_err_info_printer;
             gui_error_info_printer_init( &my_err_info_printer );
             write_err |= gui_error_info_printer_show_error_info( &my_err_info_printer, error_info, info_string );
             gui_error_info_printer_destroy( &my_err_info_printer );
         }
-        write_err |= utf8stream_writer_write_str( out_english_report, utf8stringbuf_get_string(info_string) );
+        write_err |= utf8stream_writer_write_str( out_english_report, utf8stringbuf_get_string( &info_string ) );
         write_err |= utf8stream_writer_write_str( out_english_report, "\n" );
     }
 
@@ -390,7 +363,7 @@ u8_error_t main_commands_private_report_error_info ( main_commands_t *this_,
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
