@@ -34,6 +34,8 @@
 #include "integration/consistency_drop_invisibles_test.h"
 #include "unit/ctrl_undo_redo_iterator_test.h"
 /* pencil */
+#include "unit/geometry__test.h"
+#include "unit/geometry_anchor_test.h"
 #include "unit/geometry_rectangle_test.h"
 #include "unit/geometry_connector_test.h"
 #include "unit/geometry_non_linear_scale_test.h"
@@ -84,7 +86,14 @@
 #include "meta/meta_info.h"
 #include "meta/meta_version.h"
 #include "test_runner.h"
+#if __GNUC__ >= 8
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpedantic"
+#endif
 #include <gtk/gtk.h>
+#if __GNUC__ >= 8
+#pragma GCC diagnostic pop
+#endif
 #include <stdbool.h>
 #include <stdio.h>
 
@@ -245,6 +254,8 @@ int main (int argc, char *argv[]) {
         test_runner_run_suite( &runner, consistency_drop_invisibles_test_get_suite() );
 
         /* pencil */
+        test_runner_run_suite( &runner, geometry__test_get_suite() );
+        test_runner_run_suite( &runner, geometry_anchor_test_get_suite() );
         test_runner_run_suite( &runner, geometry_rectangle_test_get_suite() );
         test_runner_run_suite( &runner, geometry_connector_test_get_suite() );
         test_runner_run_suite( &runner, geometry_non_linear_scale_test_get_suite() );
