@@ -9,13 +9,13 @@
  *  \brief Draws titles and types of relationships
  */
 
-#include "draw/draw_stereotype_image.h"
+#include "draw/draw_stereotype_icon.h"
 #include "pencil_size.h"
 #include "geometry/geometry_h_align.h"
 #include "geometry/geometry_v_align.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_dimensions.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "set/data_profile_part.h"
 #include <cairo.h>
 #include <stdint.h>
@@ -27,7 +27,7 @@
  *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct draw_diagram_label_struct {
-    draw_stereotype_image_t image_renderer;  /*!< own instance of stereotype image renderer */
+    draw_stereotype_icon_t image_renderer;  /*!< own instance of stereotype image renderer */
 };
 
 typedef struct draw_diagram_label_struct draw_diagram_label_t;
@@ -92,7 +92,7 @@ void draw_diagram_label_draw_type_and_name( const draw_diagram_label_t *this_,
 
 
 /*
-Copyright 2019-2024 Andreas Warnke
+Copyright 2019-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
