@@ -10,7 +10,7 @@
  */
 
 #include "geometry/geometry_rectangle.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 
 /*!
  *  \brief dimensions of a diagram
@@ -111,7 +111,7 @@ static inline const data_diagram_t *layout_diagram_get_data_const ( const layout
  *  \param this_ pointer to own object attributes
  *  \return id of the diagram
  */
-static inline data_row_id_t layout_diagram_get_diagram_id ( const layout_diagram_t *this_ );
+static inline data_row_t layout_diagram_get_diagram_id ( const layout_diagram_t *this_ );
 
 #include "layout_diagram.inl"
 
@@ -119,7 +119,7 @@ static inline data_row_id_t layout_diagram_get_diagram_id ( const layout_diagram
 
 
 /*
-Copyright 2018-2024 Andreas Warnke
+Copyright 2018-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
