@@ -12,20 +12,22 @@
 #include "pencil_layouter.h"
 #include "pencil_marker.h"
 #include "pencil_diagram_painter.h"
-#include "pencil_classifier_composer.h"
+#include "pencil_classifier_painter.h"
 #include "pencil_relationship_painter.h"
 #include "pencil_size.h"
 #include "pencil_error.h"
 #include "layout/layout_order.h"
+#include "layout/layout_visible_set.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_non_linear_scale.h"
+#include "geometry/geometry_grid.h"
 #include "set/data_full_id.h"
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_stat.h"
 #include "set/data_visible_set.h"
-#include "data_diagram.h"
-#include "data_id.h"
+#include "entity/data_diagram.h"
+#include "entity/data_id.h"
 #include <cairo.h>
 #include <stdint.h>
 
@@ -39,12 +41,9 @@ struct pencil_diagram_maker_struct {
     pencil_layouter_t layouter;  /* own instance of a layouter */
 
     pencil_diagram_painter_t diagram_painter;  /*!< own instance of a diagram_painter */
-    pencil_classifier_composer_t classifier_painter;  /*!< own instance of a classifier painter */
+    pencil_classifier_painter_t classifier_painter;  /*!< own instance of a classifier painter */
     pencil_relationship_painter_t relationship_painter;  /*!< own instance of a relationship_painter */
     pencil_feature_painter_t feature_painter;  /*!< own instance of a feature_painter */
-
-    double snap_to_grid_distance;  /*!< plus/minus some pixels shall snap to grid. */
-                                   /*!< This is the expected accuracy for mouse input devices */
 };
 
 typedef struct pencil_diagram_maker_struct pencil_diagram_maker_t;
@@ -94,6 +93,13 @@ static inline void pencil_diagram_maker_define_grid ( pencil_diagram_maker_t *th
                                                       cairo_t *cr
                                                     );
 
+/*!
+ *  \brief returns the geometry_grid_t
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline const geometry_grid_t *pencil_diagram_maker_get_grid_const ( const pencil_diagram_maker_t *this_ );
+
 /*!
  *  \brief layouts the chosen diagram contents into the diagram_bounds area
  *
@@ -110,6 +116,13 @@ static inline void pencil_diagram_maker_layout_elements ( pencil_diagram_maker_t
                                                           cairo_t *cr
                                                         );
 
+/*!
+ *  \brief returns the layout_visible_set_t object
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline const layout_visible_set_t *pencil_diagram_maker_get_layout_data_const ( const pencil_diagram_maker_t *this_ );
+
 /*!
  *  \brief draws the chosen diagram contents into the diagram_bounds area of the cairo drawing context
  *
@@ -182,42 +195,6 @@ void pencil_diagram_maker_private_draw_relationships ( pencil_diagram_maker_t *t
                                                        cairo_t *cr
                                                      );
 
-/*!
- *  \brief determines if the given position is on a grid line
- *
- *  \param this_ pointer to own object attributes
- *  \param x x-position
- *  \param y y-position
- *  \param out_x_on_grid flag indicating if the given x position is on a grid line
- *  \param out_y_on_grid flag indicating if the given y position is on a grid line
- */
-static inline void pencil_diagram_maker_is_pos_on_grid ( const pencil_diagram_maker_t *this_,
-                                                         double x,
-                                                         double y,
-                                                         bool *out_x_on_grid,
-                                                         bool *out_y_on_grid
-                                                       );
-
-/*!
- *  \brief determines the grid lines
- *
- *  \param this_ pointer to own object attributes
- *  \param out_x0 x-position of leftmost grid line
- *  \param out_y0 y-position of topmost grid line
- *  \param out_dx width between grid lines
- *  \param out_dy height between grid lines
- *  \param out_x_count number of x-position grid lines
- *  \param out_y_count number of y-position grid lines
- */
-static inline void pencil_diagram_maker_get_grid_lines ( const pencil_diagram_maker_t *this_,
-                                                         double *out_x0,
-                                                         double *out_y0,
-                                                         double *out_dx,
-                                                         double *out_dy,
-                                                         uint32_t *out_x_count,
-                                                         uint32_t *out_y_count
-                                                       );
-
 /*!
  *  \brief gets the layout order at a given position
  *
@@ -225,6 +202,7 @@ static inline void pencil_diagram_maker_get_grid_lines ( const pencil_diagram_ma
  *  \param obj_id object for which to determine the layout order
  *  \param x x-position
  *  \param y y-position
+ *  \param snap_to_grid_distance number of pixels by which a close-to-grid position is snapped to the grid
  *  \param out_layout_order order at given position
  *  \return PENCIL_ERROR_OUT_OF_BOUNDS if the given position x, y is not in the diagram,
  *          PENCIL_ERROR_UNKNOWN_OBJECT if the object is not in the diagram
@@ -233,6 +211,7 @@ pencil_error_t pencil_diagram_maker_get_order_at_pos ( const pencil_diagram_make
                                                        data_id_t obj_id,
                                                        double x,
                                                        double y,
+                                                       double snap_to_grid_distance,
                                                        layout_order_t* out_layout_order
                                                      );
 
@@ -257,20 +236,13 @@ pencil_error_t pencil_diagram_maker_get_feature_order_at_pos ( const pencil_diag
                                                                layout_order_t* out_layout_order
                                                              );
 
-/*!
- *  \brief returns the layout_visible_set_t object
- *
- *  \param this_ pointer to own object attributes
- */
-static inline const layout_visible_set_t *pencil_diagram_maker_get_layout_data_const ( const pencil_diagram_maker_t *this_ );
-
 #include "pencil_diagram_maker.inl"
 
 #endif  /* PENCIL_DIAGRAM_MAKER_H */
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
