@@ -9,13 +9,15 @@
  *  \brief Notifies errors in the pencil module
  */
 
+#include "u8/u8_error.h"
+
 /*!
  *  \brief error constants which explain errors which occurred in the pencil module
  */
 enum pencil_error_enum {
     PENCIL_ERROR_NONE = 0,  /*!< 0: success */
-    PENCIL_ERROR_OUT_OF_BOUNDS = 1,  /*!< 1: input parameters are out of bounds */
-    PENCIL_ERROR_UNKNOWN_OBJECT = 2,  /*!< 2: referenced object is not in current diagram */
+    PENCIL_ERROR_OUT_OF_BOUNDS = U8_ERROR_PARAM_OUT_OF_RANGE,  /*!< input parameters like coordinates are out of bounds */
+    PENCIL_ERROR_UNKNOWN_OBJECT = U8_ERROR_NOT_FOUND,  /*!< referenced object id is not in current diagram */
 };
 
 typedef enum pencil_error_enum pencil_error_t;
@@ -24,7 +26,7 @@ typedef enum pencil_error_enum pencil_error_t;
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
