@@ -15,10 +15,10 @@
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_dimensions.h"
 #include "geometry/geometry_non_linear_scale.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "set/data_visible_set.h"
 #include "set/data_small_set.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include "data_rules.h"
 #include "u8list/universal_array_index_sorter.h"
 #include <cairo.h>
@@ -88,7 +88,7 @@ void pencil_feature_layouter_do_layout ( pencil_feature_layouter_t *this_, Pango
  *  \param[out] out_features_bounds memory location where the result shall be stored. Must not be NULL.
  */
 void pencil_feature_layouter_calculate_features_bounds ( pencil_feature_layouter_t *this_,
-                                                         data_row_id_t diagramelement_id,
+                                                         data_row_t diagramelement_id,
                                                          PangoLayout *font_layout,
                                                          geometry_dimensions_t *out_features_bounds
                                                        );
@@ -177,7 +177,7 @@ void pencil_feature_layouter_private_layout_compartment ( pencil_feature_layoute
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
