@@ -26,14 +26,14 @@
 #include "layout/layout_order.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_dimensions.h"
-#include "geometry/geometry_non_linear_scale.h"
+#include "geometry/geometry_grid.h"
 #include "set/data_full_id.h"
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_stat.h"
 #include "set/data_visible_set.h"
-#include "data_diagram.h"
-#include "data_id.h"
+#include "entity/data_diagram.h"
+#include "entity/data_id.h"
 #include "data_rules.h"
 #include "u8list/universal_array_index_sorter.h"
 #include <cairo.h>
@@ -47,8 +47,7 @@ struct pencil_layouter_struct {
     const data_profile_part_t *profile;  /*!< pointer to an external stereotype-image cache */
 
     pencil_size_t pencil_size;  /*!< own instance of a pencil_size_t object, defining pen sizes, gap sizes, font sizes and colors */
-    geometry_non_linear_scale_t x_scale;  /*!< own instance of a scale object for the x-axis */
-    geometry_non_linear_scale_t y_scale;  /*!< own instance of a scale object for the y-axis */
+    geometry_grid_t grid;  /*!< own instance of a pair of scale objects to calculate positions from order numbers */
     geometry_dimensions_t default_classifier_size;  /*!< own instance of a classifier default size */
     data_rules_t rules;  /*!< own instance of modelling rules */
 
@@ -115,6 +114,13 @@ void pencil_layouter_define_grid ( pencil_layouter_t *this_,
                                    PangoLayout *font_layout
                                  );
 
+/*!
+ *  \brief returns the geometry_grid_t
+ *
+ *  \param this_ pointer to own object attributes
+ */
+static inline const geometry_grid_t *pencil_layouter_get_grid_const ( const pencil_layouter_t *this_ );
+
 /*!
  *  \brief layouts the chosen diagram contents into the diagram_bounds area
  *
@@ -198,44 +204,6 @@ pencil_error_t pencil_layouter_get_relationship_order_at_pos ( const pencil_layo
                                                                layout_order_t* out_layout_order
                                                              );
 
-/*!
- *  \brief determines if the given position is on a grid line
- *
- *  \param this_ pointer to own object attributes
- *  \param x x-position
- *  \param y y-position
- *  \param snap_distance maximum distance to the next grid line when to evaluate to "yes, on grid"
- *  \param out_x_on_grid flag indicating if the given x position is on a grid line
- *  \param out_y_on_grid flag indicating if the given y position is on a grid line
- */
-static inline void pencil_layouter_is_pos_on_grid ( const pencil_layouter_t *this_,
-                                                    double x,
-                                                    double y,
-                                                    double snap_distance,
-                                                    bool *out_x_on_grid,
-                                                    bool *out_y_on_grid
-                                                  );
-
-/*!
- *  \brief determines the grid lines
- *
- *  \param this_ pointer to own object attributes
- *  \param out_x0 x-position of leftmost grid line
- *  \param out_y0 y-position of topmost grid line
- *  \param out_dx width between grid lines
- *  \param out_dy height between grid lines
- *  \param out_x_count number of x-position grid lines
- *  \param out_y_count number of y-position grid lines
- */
-static inline void pencil_layouter_get_grid_lines ( const pencil_layouter_t *this_,
-                                                    double *out_x0,
-                                                    double *out_y0,
-                                                    double *out_dx,
-                                                    double *out_dy,
-                                                    uint32_t *out_x_count,
-                                                    uint32_t *out_y_count
-                                                  );
-
 /*!
  *  \brief proposes a default classifier bounds rectangle
  *
@@ -249,7 +217,7 @@ void pencil_layouter_private_propose_default_classifier_size ( pencil_layouter_t
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
