@@ -10,9 +10,9 @@
  */
 
 #include "geometry/geometry_rectangle.h"
-#include "data_diagram.h"
+#include "entity/data_diagram.h"
 #include "set/data_small_set.h"
-#include "data_id.h"
+#include "entity/data_id.h"
 #include "set/data_visible_set.h"
 #include <cairo.h>
 #include <stdint.h>
@@ -65,7 +65,7 @@ void pencil_marker_mark_selected_rectangle ( const pencil_marker_t *this_, geome
 
 
 /*
-Copyright 2016-2024 Andreas Warnke
+Copyright 2016-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
