@@ -11,15 +11,14 @@
 
 #include "pencil_size.h"
 #include "layout/layout_visible_set.h"
-#include "pencil_label_layout_helper.h"
+#include "pencil_floating_label_layouter.h"
 #include "draw/draw_relationship_label.h"
-#include "draw/draw_stereotype_image.h"
 #include "geometry/geometry_rectangle.h"
 #include "set/data_profile_part.h"
 #include "set/data_small_set.h"
 #include "set/data_visible_set.h"
-#include "data_diagram.h"
-#include "data_id.h"
+#include "entity/data_diagram.h"
+#include "entity/data_id.h"
 #include "u8list/universal_array_index_sorter.h"
 #include <cairo.h>
 #include <stdint.h>
@@ -37,7 +36,7 @@ struct pencil_rel_label_layouter_struct {
     const pencil_size_t *pencil_size;  /*!< pointer to an instance of a pencil_size_t object, defining pen sizes, gap sizes, font sizes and colors */
 
     draw_relationship_label_t draw_relationship_label;  /*!< collection of draw label functions */
-    pencil_label_layout_helper_t label_layout_helper;   /*!< collection of layout label functions */
+    pencil_floating_label_layouter_t label_floater;   /*!< collection of layout label functions */
 };
 
 typedef struct pencil_rel_label_layouter_struct pencil_rel_label_layouter_t;
@@ -117,7 +116,7 @@ void pencil_rel_label_layouter_private_propose_solutions ( pencil_rel_label_layo
 
 
 /*
-Copyright 2019-2024 Andreas Warnke
+Copyright 2019-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
