@@ -6,9 +6,9 @@
 #include <assert.h>
 #include <math.h>
 
-int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
-                                            const geometry_rectangle_t *rect_a,
-                                            const geometry_rectangle_t *rect_b )
+int geometry_rectangle_init_by_difference_max( geometry_rectangle_t *this_,
+                                               const geometry_rectangle_t *rect_a,
+                                               const geometry_rectangle_t *rect_b )
 {
     U8_TRACE_BEGIN();
     assert( NULL != rect_a );
@@ -40,10 +40,7 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
         const bool check_bottom = (( b_bottom > a_top )&&( b_bottom < a_bottom ));
         const bool check_left = (( b_left > a_left )&&( b_left < a_right ));
         const bool check_right = (( b_right > a_left )&&( b_right < a_right ));
-        bool keep_top_part = false;
-        bool keep_bottom_part = false;
-        bool keep_left_part = false;
-        bool keep_right_part = false;
+        geometry_direction_t keep;
         if ( check_top )
         {
             if ( check_bottom )
@@ -64,22 +61,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                             {
                                 if (area_top>area_right)
                                 {
-                                    keep_top_part = true;
+                                    keep = GEOMETRY_DIRECTION_UP;
                                 }
                                 else  /* area_right is bigger */
                                 {
-                                    keep_right_part = true;
+                                    keep = GEOMETRY_DIRECTION_RIGHT;
                                 }
                             }
                             else  /* area_left is bigger */
                             {
                                 if (area_left>area_right)
                                 {
-                                    keep_left_part = true;
+                                    keep = GEOMETRY_DIRECTION_LEFT;
                                 }
                                 else  /* area_right is bigger */
                                 {
-                                    keep_right_part = true;
+                                    keep = GEOMETRY_DIRECTION_RIGHT;
                                 }
                             }
                         }
@@ -89,22 +86,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                             {
                                 if (area_bottom>area_right)
                                 {
-                                    keep_bottom_part = true;
+                                    keep = GEOMETRY_DIRECTION_DOWN;
                                 }
                                 else  /* area_right is bigger */
                                 {
-                                    keep_right_part = true;
+                                    keep = GEOMETRY_DIRECTION_RIGHT;
                                 }
                             }
                             else  /* area_left is bigger */
                             {
                                 if (area_left>area_right)
                                 {
-                                    keep_left_part = true;
+                                    keep = GEOMETRY_DIRECTION_LEFT;
                                 }
                                 else  /* area_right is bigger */
                                 {
-                                    keep_right_part = true;
+                                    keep = GEOMETRY_DIRECTION_RIGHT;
                                 }
                             }
                         }
@@ -120,22 +117,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         {
                             if (area_top>area_left)
                             {
-                                keep_top_part = true;
+                                keep = GEOMETRY_DIRECTION_UP;
                             }
                             else  /* area_left is bigger */
                             {
-                                keep_left_part = true;
+                                keep = GEOMETRY_DIRECTION_LEFT;
                             }
                         }
                         else  /* area_bottom is bigger */
                         {
                             if (area_bottom>area_left)
                             {
-                                keep_bottom_part = true;
+                                keep = GEOMETRY_DIRECTION_DOWN;
                             }
                             else  /* area_left is bigger */
                             {
-                                keep_left_part = true;
+                                keep = GEOMETRY_DIRECTION_LEFT;
                             }
                         }
                     }
@@ -153,22 +150,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         {
                             if (area_top>area_right)
                             {
-                                keep_top_part = true;
+                                keep = GEOMETRY_DIRECTION_UP;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                         else  /* area_bottom is bigger */
                         {
                             if (area_bottom>area_right)
                             {
-                                keep_bottom_part = true;
+                                keep = GEOMETRY_DIRECTION_DOWN;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                     }
@@ -178,11 +175,11 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         /* 2 possible solutions */
                         if (( b_top-a_top )>( a_bottom-b_bottom ))
                         {
-                            keep_top_part = true;
+                            keep = GEOMETRY_DIRECTION_UP;
                         }
                         else
                         {
-                            keep_bottom_part = true;
+                            keep = GEOMETRY_DIRECTION_DOWN;
                         }
                     }
                 }
@@ -202,22 +199,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         {
                             if (area_top>area_right)
                             {
-                                keep_top_part = true;
+                                keep = GEOMETRY_DIRECTION_UP;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                         else  /* area_left is bigger */
                         {
                             if (area_left>area_right)
                             {
-                                keep_left_part = true;
+                                keep = GEOMETRY_DIRECTION_LEFT;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                     }
@@ -229,11 +226,11 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         const double area_left = ( b_left-a_left ) * geometry_rectangle_get_height( rect_a );
                         if (area_top>area_left)
                         {
-                            keep_top_part = true;
+                            keep = GEOMETRY_DIRECTION_UP;
                         }
                         else  /* area_left is bigger */
                         {
-                            keep_left_part = true;
+                            keep = GEOMETRY_DIRECTION_LEFT;
                         }
                     }
 
@@ -248,18 +245,18 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         const double area_right = ( a_right-b_right ) * geometry_rectangle_get_height( rect_a );
                         if (area_top>area_right)
                         {
-                            keep_top_part = true;
+                            keep = GEOMETRY_DIRECTION_UP;
                         }
                         else  /* area_right is bigger */
                         {
-                            keep_right_part = true;
+                            keep = GEOMETRY_DIRECTION_RIGHT;
                         }
                     }
                     else  /* ! check_right */
                     {
                         U8_TRACE_INFO( "to." );
                         /* 1 solution */
-                        keep_top_part = true;
+                        keep = GEOMETRY_DIRECTION_UP;
                     }
                 }
             }
@@ -281,22 +278,22 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         {
                             if (area_bottom>area_right)
                             {
-                                keep_bottom_part = true;
+                                keep = GEOMETRY_DIRECTION_DOWN;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                         else  /* area_left is bigger */
                         {
                             if (area_left>area_right)
                             {
-                                keep_left_part = true;
+                                keep = GEOMETRY_DIRECTION_LEFT;
                             }
                             else  /* area_right is bigger */
                             {
-                                keep_right_part = true;
+                                keep = GEOMETRY_DIRECTION_RIGHT;
                             }
                         }
                     }
@@ -308,11 +305,11 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         const double area_left = ( b_left-a_left ) * geometry_rectangle_get_height( rect_a );
                         if (area_bottom>area_left)
                         {
-                            keep_bottom_part = true;
+                            keep = GEOMETRY_DIRECTION_DOWN;
                         }
                         else  /* area_left is bigger */
                         {
-                            keep_left_part = true;
+                            keep = GEOMETRY_DIRECTION_LEFT;
                         }
                     }
 
@@ -327,18 +324,18 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         const double area_right = ( a_right-b_right ) * geometry_rectangle_get_height( rect_a );
                         if (area_bottom>area_right)
                         {
-                            keep_bottom_part = true;
+                            keep = GEOMETRY_DIRECTION_DOWN;
                         }
                         else  /* area_right is bigger */
                         {
-                            keep_right_part = true;
+                            keep = GEOMETRY_DIRECTION_RIGHT;
                         }
                     }
                     else  /* ! check_right */
                     {
                         U8_TRACE_INFO( "bo." );
                         /* 1 solution */
-                        keep_bottom_part = true;
+                        keep = GEOMETRY_DIRECTION_DOWN;
                     }
                 }
             }
@@ -352,18 +349,18 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                         /* 2 possible solutions */
                         if (( b_left-a_left )>( a_right-b_right ))
                         {
-                            keep_left_part = true;
+                            keep = GEOMETRY_DIRECTION_LEFT;
                         }
                         else
                         {
-                            keep_right_part = true;
+                            keep = GEOMETRY_DIRECTION_RIGHT;
                         }
                     }
                     else  /* ! check_right */
                     {
                         U8_TRACE_INFO( "le." );
                         /* 1 solution */
-                        keep_left_part = true;
+                        keep = GEOMETRY_DIRECTION_LEFT;
                     }
 
                 }
@@ -373,42 +370,43 @@ int geometry_rectangle_init_by_difference ( geometry_rectangle_t *this_,
                     {
                         U8_TRACE_INFO( "ri." );
                         /* 1 solution */
-                        keep_right_part = true;
+                        keep = GEOMETRY_DIRECTION_RIGHT;
                     }
                     else  /* ! check_right */
                     {
                         U8_TRACE_INFO( "0." );
                         /* rect_b contains rect_a, result is empty */
+                        keep = GEOMETRY_DIRECTION_CENTER;
                     }
                 }
             }
         }
 
-        if ( keep_top_part )
+        if ( keep == GEOMETRY_DIRECTION_UP )
         {
             assert ( check_top );
             U8_TRACE_INFO( "-top-" );
             geometry_rectangle_init ( this_, a_left, a_top, geometry_rectangle_get_width( rect_a ), b_top-a_top );
         }
-        else if ( keep_bottom_part )
+        else if ( keep == GEOMETRY_DIRECTION_DOWN )
         {
             assert ( check_bottom );
             U8_TRACE_INFO( "-bottom-" );
             geometry_rectangle_init ( this_, a_left, b_bottom, geometry_rectangle_get_width( rect_a ), a_bottom-b_bottom );
         }
-        else if ( keep_left_part )
+        else if ( keep == GEOMETRY_DIRECTION_LEFT )
         {
             assert ( check_left );
             U8_TRACE_INFO( "-left-" );
             geometry_rectangle_init ( this_, a_left, a_top, b_left-a_left, geometry_rectangle_get_height( rect_a ) );
         }
-        else if ( keep_right_part )
+        else if ( keep == GEOMETRY_DIRECTION_RIGHT )
         {
             assert ( check_right );
             U8_TRACE_INFO( "-right-" );
             geometry_rectangle_init ( this_, b_right, a_top, a_right-b_right, geometry_rectangle_get_height( rect_a ) );
         }
-        else
+        else  /* GEOMETRY_DIRECTION_CENTER */
         {
             U8_TRACE_INFO( "-none-" );
             geometry_rectangle_init ( this_, a_left, a_top, 0.0, 0.0 );
