@@ -606,31 +606,6 @@ void pencil_relationship_painter_draw ( pencil_relationship_painter_t *this_,
                                                      cr
                                                    );
 
-#ifdef LAYOUT_VISIBLE_SET_DRAW_FOR_DEBUG
-        /* draw the rectangles */
-        {
-            const geometry_rectangle_t bounds
-                = geometry_connector_get_bounding_rectangle( connector_shape );
-            const geometry_rectangle_t *const relation_label_box
-                = layout_relationship_get_label_box_const( layouted_relationship );
-
-            cairo_set_source_rgba( cr, 0.5, 1.0, 0.6, 0.5 );
-            cairo_rectangle ( cr,
-                              geometry_rectangle_get_left ( &bounds ),
-                              geometry_rectangle_get_top ( &bounds ),
-                              geometry_rectangle_get_width ( &bounds ),
-                              geometry_rectangle_get_height ( &bounds )
-                            );
-            cairo_rectangle ( cr,
-                              geometry_rectangle_get_left ( relation_label_box ),
-                              geometry_rectangle_get_top ( relation_label_box ),
-                              geometry_rectangle_get_width ( relation_label_box ),
-                              geometry_rectangle_get_height ( relation_label_box )
-                            );
-            cairo_stroke (cr);
-        }
-#endif
-
         /* draw markers */
         if ( mark_selected )
         {
@@ -656,7 +631,7 @@ void pencil_relationship_painter_draw ( pencil_relationship_painter_t *this_,
 
 
 /*
-Copyright 2017-2024 Andreas Warnke
+Copyright 2017-2025 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
