@@ -7,6 +7,7 @@
 #include "set/data_visible_set.h"
 #include "set/data_profile_part.h"
 #include "test_data/test_data_setup.h"
+#include "test_data/test_data_evaluation.h"
 #include "u8/u8_trace.h"
 #include "test_fixture.h"
 #include "test_expect.h"
@@ -18,19 +19,10 @@ static void tear_down( test_fixture_t *fix );
 static test_case_result_t render_good_cases_no_output( test_fixture_t *fix );
 static test_case_result_t render_good_cases( test_fixture_t *fix );
 static test_case_result_t render_challenging_cases( test_fixture_t *fix );
+/*
+ * There is no value in rendering too full diagrams
 static test_case_result_t render_edge_cases( test_fixture_t *fix );
-
-/*!
- *  \brief draws rectangles for layout_visible_set_analyze to indicate overlaps
- *
- *  \param data pointer that is passed to overlap_callback
- *  \param rect_a pointer to a rectangle that overlaps with rect_b
- *  \param rect_b pointer to a rectangle that overlaps with rect_a
- */
-void pencil_diagram_maker_test_draw_rects_callback ( void *data,
-                                                     const geometry_rectangle_t *rect_a,
-                                                     const geometry_rectangle_t *rect_b
-                                                   );
+*/
 
 test_suite_t pencil_diagram_maker_test_get_suite(void)
 {
@@ -45,7 +37,9 @@ test_suite_t pencil_diagram_maker_test_get_suite(void)
     const test_category_t ON_QUEST = TEST_CATEGORY_INTEGRATION | TEST_CATEGORY_QUEST;
     test_suite_add_special_test_case( &result, "render_good_cases", ON_QUEST, &render_good_cases );
     test_suite_add_special_test_case( &result, "render_challenging_cases", ON_QUEST, &render_challenging_cases );
+/*
     test_suite_add_special_test_case( &result, "render_edge_cases", ON_QUEST, &render_edge_cases );
+*/
     return result;
 }
 
@@ -111,7 +105,7 @@ static void render_to_file( cairo_surface_t *surface,
     /* create filename */
     char filename_buf[48]="";
     utf8stringbuf_t filename = UTF8STRINGBUF(filename_buf);
-    utf8stringbuf_append_str( filename, "test_pencil" );
+    utf8stringbuf_append_str( &filename, "test_pencil" );
 
     const unsigned int variant = test_data_setup_get_variant( ts_case_setup );
     switch ( test_data_setup_get_mode( ts_case_setup ) )
@@ -119,36 +113,36 @@ static void render_to_file( cairo_surface_t *surface,
         default:
         case TEST_DATA_SETUP_MODE_GOOD_CASES:
         {
-            utf8stringbuf_append_str( filename, "_good" );
+            utf8stringbuf_append_str( &filename, "_good" );
         }
         break;
 
         case TEST_DATA_SETUP_MODE_CHALLENGING_CASES:
         {
-            utf8stringbuf_append_str( filename, "_cllg" );
+            utf8stringbuf_append_str( &filename, "_cllg" );
         }
         break;
 
         case TEST_DATA_SETUP_MODE_EDGE_CASES:
         {
-            utf8stringbuf_append_str( filename, "_edge" );
+            utf8stringbuf_append_str( &filename, "_edge" );
         }
         break;
     }
-    utf8stringbuf_append_str( filename, "_" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_ERROR ) );
-    utf8stringbuf_append_str( filename, "e_" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_WARNING ) );
-    utf8stringbuf_append_str( filename, "w_" );
-    utf8stringbuf_append_int( filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_EXPORTED ) );
-    utf8stringbuf_append_str( filename, "ok_" );
-    utf8stringbuf_append_int( filename, variant );
-    utf8stringbuf_append_str( filename, ".png" );
-    U8_TRACE_INFO_STR("filename:", utf8stringbuf_get_string( filename ));
+    utf8stringbuf_append_str( &filename, "_" );
+    utf8stringbuf_append_int( &filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_ERROR ) );
+    utf8stringbuf_append_str( &filename, "e_" );
+    utf8stringbuf_append_int( &filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_WARNING ) );
+    utf8stringbuf_append_str( &filename, "w_" );
+    utf8stringbuf_append_int( &filename, data_stat_get_series_count( render_stats, DATA_STAT_SERIES_EXPORTED ) );
+    utf8stringbuf_append_str( &filename, "ok_" );
+    utf8stringbuf_append_int( &filename, variant );
+    utf8stringbuf_append_str( &filename, ".png" );
+    U8_TRACE_INFO_STR("filename:", utf8stringbuf_get_string( &filename ));
 
     /* finish surface */
     const cairo_status_t png_result
-        = cairo_surface_write_to_png ( surface, utf8stringbuf_get_string( filename ) );
+        = cairo_surface_write_to_png ( surface, utf8stringbuf_get_string( &filename ) );
     TEST_ENVIRONMENT_ASSERT( CAIRO_STATUS_SUCCESS == png_result );
     U8_TRACE_END();
 }
@@ -195,6 +189,8 @@ static test_case_result_t render_good_cases( test_fixture_t *fix )
     assert( fix != NULL );
     test_data_setup_t ts_setup;
     test_data_setup_init( &ts_setup, TEST_DATA_SETUP_MODE_GOOD_CASES );
+    test_data_evaluation_t ts_eval;
+    test_data_evaluation_init( &ts_eval );
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
         /* setup */
@@ -210,11 +206,12 @@ static test_case_result_t render_good_cases( test_fixture_t *fix )
         data_stat_init( &layout_stats );
         pencil_diagram_maker_define_grid( &((*fix).painter), (*fix).diagram_bounds, (*fix).cr );
         pencil_diagram_maker_layout_elements( &((*fix).painter), NULL, (*fix).cr );
-        layout_visible_set_analyze( pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
-                                    &layout_stats,
-                                    pencil_diagram_maker_test_draw_rects_callback,
-                                    (*fix).cr /* the user data of type void* */
-                                  );
+        test_data_evaluation_analyze( &ts_eval,
+                                      pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
+                                      &layout_stats,
+                                      pencil_diagram_maker_test_draw_rects_callback,
+                                      (*fix).cr /* the user data of type void* */
+                                    );
         pencil_diagram_maker_draw ( &((*fix).painter),
                                     void_id,
                                     void_id,
@@ -226,6 +223,7 @@ static test_case_result_t render_good_cases( test_fixture_t *fix )
         render_to_file( (*fix).surface, &ts_setup, &layout_stats );
         data_stat_destroy( &layout_stats );
     }
+    test_data_evaluation_destroy( &ts_eval );
     test_data_setup_destroy( &ts_setup );
     return TEST_CASE_RESULT_OK;
 }
@@ -235,6 +233,8 @@ static test_case_result_t render_challenging_cases( test_fixture_t *fix )
     assert( fix != NULL );
     test_data_setup_t ts_setup;
     test_data_setup_init( &ts_setup, TEST_DATA_SETUP_MODE_CHALLENGING_CASES );
+    test_data_evaluation_t ts_eval;
+    test_data_evaluation_init( &ts_eval );
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
         /* setup */
@@ -250,11 +250,12 @@ static test_case_result_t render_challenging_cases( test_fixture_t *fix )
         data_stat_init( &layout_stats );
         pencil_diagram_maker_define_grid( &((*fix).painter), (*fix).diagram_bounds, (*fix).cr );
         pencil_diagram_maker_layout_elements( &((*fix).painter), NULL, (*fix).cr );
-        layout_visible_set_analyze( pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
-                                    &layout_stats,
-                                    pencil_diagram_maker_test_draw_rects_callback,
-                                    (*fix).cr /* the user data of type void* */
-                                  );
+        test_data_evaluation_analyze( &ts_eval,
+                                      pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
+                                      &layout_stats,
+                                      pencil_diagram_maker_test_draw_rects_callback,
+                                      (*fix).cr /* the user data of type void* */
+                                    );
         pencil_diagram_maker_draw ( &((*fix).painter),
                                     void_id,
                                     void_id,
@@ -266,22 +267,26 @@ static test_case_result_t render_challenging_cases( test_fixture_t *fix )
         render_to_file( (*fix).surface, &ts_setup, &layout_stats );
         data_stat_destroy( &layout_stats );
     }
+    test_data_evaluation_destroy( &ts_eval );
     test_data_setup_destroy( &ts_setup );
     return TEST_CASE_RESULT_OK;
 }
 
+/*
 static test_case_result_t render_edge_cases( test_fixture_t *fix )
 {
     assert( fix != NULL );
     test_data_setup_t ts_setup;
     test_data_setup_init( &ts_setup, TEST_DATA_SETUP_MODE_EDGE_CASES );
+    test_data_evaluation_t ts_eval;
+    test_data_evaluation_init( &ts_eval );
     for ( ; test_data_setup_is_valid_variant( &ts_setup ); test_data_setup_next_variant( &ts_setup ) )
     {
-        /* setup */
+        / * setup * /
         test_data_setup_get_variant_data( &ts_setup, &((*fix).data_set) );
         draw_background( &((*fix).diagram_bounds), (*fix).cr );
 
-        /* perform test: draw diagram */
+        / * perform test: draw diagram * /
         data_id_t void_id;
         data_id_init_void( &void_id );
         data_small_set_t void_set;
@@ -290,11 +295,12 @@ static test_case_result_t render_edge_cases( test_fixture_t *fix )
         data_stat_init( &layout_stats );
         pencil_diagram_maker_define_grid( &((*fix).painter), (*fix).diagram_bounds, (*fix).cr );
         pencil_diagram_maker_layout_elements( &((*fix).painter), NULL, (*fix).cr );
-        layout_visible_set_analyze( pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
-                                    &layout_stats,
-                                    pencil_diagram_maker_test_draw_rects_callback,
-                                    (*fix).cr /* the user data of type void* */
-                                  );
+        test_data_evaluation_analyze( &ts_eval,
+                                      pencil_diagram_maker_get_layout_data_const( &((*fix).painter) ),
+                                      &layout_stats,
+                                      pencil_diagram_maker_test_draw_rects_callback,
+                                      (*fix).cr / * the user data of type void* * /
+                                    );
         pencil_diagram_maker_draw ( &((*fix).painter),
                                     void_id,
                                     void_id,
@@ -302,13 +308,15 @@ static test_case_result_t render_edge_cases( test_fixture_t *fix )
                                     (*fix).cr
                                   );
 
-        /* check result */
+        / * check result * /
         render_to_file( (*fix).surface, &ts_setup, &layout_stats );
         data_stat_destroy( &layout_stats );
     }
+    test_data_evaluation_destroy( &ts_eval );
     test_data_setup_destroy( &ts_setup );
     return TEST_CASE_RESULT_OK;
 }
+*/
 
 void pencil_diagram_maker_test_draw_rects_callback ( void *data,
                                                      const geometry_rectangle_t *rect_a,
@@ -318,39 +326,41 @@ void pencil_diagram_maker_test_draw_rects_callback ( void *data,
     assert( NULL != rect_a );
     assert( NULL != rect_b );
     cairo_t *cr = data;
-    cairo_set_source_rgba( cr, 1.0, 0.8, 0.8, 1.0 );
-    cairo_rectangle ( cr,
-                      geometry_rectangle_get_left ( rect_a ),
-                      geometry_rectangle_get_top ( rect_a ),
-                      geometry_rectangle_get_width ( rect_a ),
-                      geometry_rectangle_get_height ( rect_a )
-                    );
-    cairo_rectangle ( cr,
-                      geometry_rectangle_get_left ( rect_b ),
-                      geometry_rectangle_get_top ( rect_b ),
-                      geometry_rectangle_get_width ( rect_b ),
-                      geometry_rectangle_get_height ( rect_b )
-                    );
-    cairo_stroke (cr);
+    cairo_set_source_rgba( cr, 1.0, 0.6, 0.65, 1.0 );
+    cairo_rectangle( cr,
+                     geometry_rectangle_get_left ( rect_a ),
+                     geometry_rectangle_get_top ( rect_a ),
+                     geometry_rectangle_get_width ( rect_a ),
+                     geometry_rectangle_get_height ( rect_a )
+                   );
+    cairo_rectangle( cr,
+                     geometry_rectangle_get_left ( rect_b ),
+                     geometry_rectangle_get_top ( rect_b ),
+                     geometry_rectangle_get_width ( rect_b ),
+                     geometry_rectangle_get_height ( rect_b )
+                   );
+    cairo_stroke( cr );
 
     geometry_rectangle_t isect;
     const int err_no_intersect = geometry_rectangle_init_by_intersect( &isect, rect_a, rect_b );
     if ( err_no_intersect == 0 )
     {
-        cairo_rectangle ( cr,
-                        geometry_rectangle_get_left ( &isect ),
-                        geometry_rectangle_get_top ( &isect ),
-                        geometry_rectangle_get_width ( &isect ),
-                        geometry_rectangle_get_height ( &isect )
-                        );
-        cairo_fill (cr);
+        geometry_rectangle_enlarge( &isect, 6.0, 6.0 );
+        geometry_rectangle_shift( &isect, -3.0, -3.0 );
+        cairo_rectangle( cr,
+                         geometry_rectangle_get_left ( &isect ),
+                         geometry_rectangle_get_top ( &isect ),
+                         geometry_rectangle_get_width ( &isect ),
+                         geometry_rectangle_get_height ( &isect )
+                       );
+        cairo_fill( cr );
         geometry_rectangle_destroy( &isect );
     }
 }
 
 
 /*
- * Copyright 2021-2024 Andreas Warnke
+ * Copyright 2021-2025 Andreas Warnke
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
