@@ -10,6 +10,7 @@
 static test_fixture_t * set_up();
 static void tear_down( test_fixture_t *fix );
 static test_case_result_t test_scale_conversion( test_fixture_t *fix );
+static test_case_result_t test_buffer_exceeded( test_fixture_t *fix );
 
 test_suite_t geometry_non_linear_scale_test_get_suite(void)
 {
@@ -21,6 +22,7 @@ test_suite_t geometry_non_linear_scale_test_get_suite(void)
                      &tear_down
                    );
     test_suite_add_test_case( &result, "test_scale_conversion", &test_scale_conversion );
+    test_suite_add_test_case( &result, "test_buffer_exceeded", &test_buffer_exceeded );
     return result;
 }
 
@@ -81,6 +83,26 @@ static test_case_result_t test_scale_conversion( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+static test_case_result_t test_buffer_exceeded( test_fixture_t *fix )
+{
+    geometry_non_linear_scale_t my_scale;
+    geometry_non_linear_scale_init ( &my_scale, 0.0, 1000.0 * ( GEOMETRY_NON_LINEAR_SCALE_MAX_POINTS - 1 ) );
+
+    for ( int32_t step = 0; step < ( GEOMETRY_NON_LINEAR_SCALE_MAX_POINTS - 2 ); step ++ )
+    {
+        const u8_error_t err0 = geometry_non_linear_scale_add_order( &my_scale, step + 1 );
+        TEST_EXPECT_EQUAL_INT( U8_ERROR_NONE, err0 );
+    }
+    const u8_error_t err1 = geometry_non_linear_scale_add_order( &my_scale, GEOMETRY_NON_LINEAR_SCALE_MAX_POINTS - 1 );
+    TEST_EXPECT_EQUAL_INT( U8_ERROR_ARRAY_BUFFER_EXCEEDED, err1 );
+
+    double not_the_dropped = geometry_non_linear_scale_get_closest_fix_location( &my_scale, 3000.1 );
+    TEST_EXPECT_EQUAL_FLOAT( 3000.0, not_the_dropped );
+
+    geometry_non_linear_scale_destroy ( &my_scale );
+    return TEST_CASE_RESULT_OK;
+}
+
 
 /*
  * Copyright 2016-2025 Andreas Warnke
